@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bookmarkPlugin.h"
@@ -13,13 +13,13 @@
 #include <QtGui>
 
 
-bookmarkPlugin::bookmarkPlugin(QWidget* parent) : QMenu(parent)
+bookmarkPlugin::bookmarkPlugin(QWidget* parentw) : QMenu(parentw)
 {
     setObjectName(QString::fromUtf8("menuBookmarks"));
     setTitle(QApplication::translate("c2bEditor", "&Bookmarks", 0, QApplication::UnicodeUTF8));
     connect(c2bSettingsP, SIGNAL(newSettings()), this, SLOT(init()));
-    fsw = new QFileSystemWatcher(this);
-    connect(fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(parseBookmarks()));
+    _fsw = new QFileSystemWatcher(this);
+    connect(_fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(parseBookmarks()));
     init();
 }
 
@@ -29,15 +29,15 @@ bookmarkPlugin::~bookmarkPlugin()
 
 void bookmarkPlugin::init()
 {
-    QString nfn = c2bSettingsP->fileName("cb2Bib/NetworkFile");
-    if (nfn == bookmark_file)
+    const QString nfn(c2bSettingsP->fileName("cb2Bib/NetworkFile"));
+    if (nfn == _bookmark_file)
         return;
     if (QFileInfo(nfn).exists())
     {
-        if (!bookmark_file.isEmpty())
-            fsw->removePath(bookmark_file);
-        bookmark_file = nfn;
-        fsw->addPath(bookmark_file);
+        if (!_bookmark_file.isEmpty())
+            _fsw->removePath(_bookmark_file);
+        _bookmark_file = nfn;
+        _fsw->addPath(_bookmark_file);
     }
     parseBookmarks();
 }
@@ -45,10 +45,10 @@ void bookmarkPlugin::init()
 void bookmarkPlugin::parseBookmarks()
 {
     clear();
-    const QString bmf = c2bUtils::fileToString(bookmark_file);
-    QStringList bookmarks = bmf.split("\n", QString::KeepEmptyParts);
-    QRegExp _bookmark("^editorbookmark=");
-    QRegExp _separator("^editorbookmark=\\s*$");
+    const QString bmf(c2bUtils::fileToString(_bookmark_file));
+    QStringList bookmarks(bmf.split('\n', QString::KeepEmptyParts));
+    const QRegExp _bookmark("^editorbookmark=");
+    const QRegExp _separator("^editorbookmark=\\s*$");
     for (int i = 0; i < bookmarks.count(); ++i)
     {
         if (bookmarks.at(i).contains(_separator))
@@ -59,13 +59,13 @@ void bookmarkPlugin::parseBookmarks()
         if (bookmarks.at(i).contains(_bookmark))
         {
             bookmarks[i].remove(_bookmark);
-            QStringList bm_parts = bookmarks.at(i).split("|", QString::KeepEmptyParts);
+            const QStringList bm_parts(bookmarks.at(i).split('|', QString::KeepEmptyParts));
             if (bm_parts.count() != 4)
             {
-                qDebug(tr("[cb2bib] parseBookmarks: Syntax error at '%1'").arg(bookmarks.at(i)).toLatin1());
+                c2bUtils::warn(tr("bookmarkPlugin::parseBookmarks: Syntax error at '%1'").arg(bookmarks.at(i)));
                 continue;
             }
-            QAction* act = addAction(bm_parts.at(0), this, SLOT(actionTriggered()));
+            QAction* act = addAction(bm_parts.at(0), this, SLOT(openBookmark()));
             act->setData(bm_parts.at(1));
             act->setStatusTip(QString("%1  [%2]").arg(bm_parts.at(0)).arg(bm_parts.at(1)));
             act->setShortcut(bm_parts.at(2));
@@ -95,15 +95,15 @@ QString bookmarkPlugin::iconProvider(const QString& fn, const QString& iconFile)
     return ":/icons/icons/application-x-none.png";
 }
 
-void bookmarkPlugin::actionTriggered()
+void bookmarkPlugin::openBookmark()
 {
     QAction* act = static_cast<QAction*>(sender());
     if (act)
     {
-        QString fn = act->data().toString();
+        const QString fn(act->data().toString());
         if (fn.endsWith(".bib"))  // Open BiBTeX files internally
             emit openFile(fn);
         else
-            c2b::openFile(fn);
+            c2bUtils::openFile(fn, parentWidget());
     }
 }
