@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef BOOKMARKPLUGIN_H
@@ -18,7 +18,7 @@ class bookmarkPlugin : public QMenu
     Q_OBJECT
 
 public:
-    bookmarkPlugin(QWidget* parent = 0);
+    bookmarkPlugin(QWidget* parentw = 0);
     ~bookmarkPlugin();
 
 
@@ -28,14 +28,14 @@ signals:
 
 
 private:
-    QFileSystemWatcher* fsw;
-    QString bookmark_file;
+    QFileSystemWatcher* _fsw;
+    QString _bookmark_file;
     QString iconProvider(const QString& fn, const QString& iconFile);
 
 
 private slots:
-    void actionTriggered();
     void init();
+    void openBookmark();
     void parseBookmarks();
 
 };
