@@ -1,19 +1,21 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2B_H
 #define C2B_H
 
 #include "c2bBibParser.h"
-#include "c2bMetaPreparser.h"
-#include "c2bNetwork.h"
 #include "c2bNetworkQueryInfo.h"
 
+#include <metadataParser.h>
+#include <network.h>
+
 #include <QObject>
 
+class QProgressDialog;
 class QWidget;
 
 
@@ -23,23 +25,13 @@ class c2b : public QObject
     Q_OBJECT
 
 public:
-    c2b(QWidget* main, QObject* parent = 0);
+    c2b(QWidget* main, QObject* parento = 0);
     ~c2b();
 
     // Actions
-    inline static void displayHelp(const QString& url)
+    inline static const QString documentMetadata(const QString& fn)
     {
-        network()->openFile(url);
-    }
-
-    inline static void openFile(const QString& fn)
-    {
-        network()->openFile(fn);
-    }
-
-    inline static const QString fileMetadata(const QString& fn)
-    {
-        return metaPreparser()->metadata(fn);
+        return metaParser()->metadata(fn);
     }
 
     inline static const QString encodeLink(const QString& ln)
@@ -69,7 +61,7 @@ public:
         return instance()->c2b_main;
     }
 
-    inline static c2bNetwork* network()
+    inline static network* net()
     {
         return instance()->c2b_network;
     }
@@ -84,14 +76,15 @@ public:
         return instance()->c2b_bibparser;
     }
 
-    inline static c2bMetaPreparser* metaPreparser()
+    inline static metadataParser* metaParser()
     {
-        return instance()->c2b_metapreparser;
+        return instance()->c2b_metadataparser;
     }
 
 
 public slots:
-    static void Configure();
+    static void configure(int index = -1);
+    void exitRequested();
 
 
 signals:
@@ -100,11 +93,12 @@ signals:
 
 
 private:
+    QProgressDialog* downloadProgress;
     QWidget* c2b_main;
     c2bBibParser* c2b_bibparser;
-    c2bMetaPreparser* c2b_metapreparser;
-    c2bNetwork* c2b_network;
     c2bNetworkQueryInfo* c2b_netqinf;
+    metadataParser* c2b_metadataparser;
+    network* c2b_network;
     static c2b* c2b_single_instance;
 
     inline void emitMessage(const QString& message)
@@ -117,6 +111,12 @@ private:
         emit searchInFiles(string, fn);
     }
 
+
+private slots:
+    void proxyAuthenticationRequired(const QNetworkProxy& proxy, QAuthenticator* auth);
+    void showMessage(const QString& title, const QString& ms);
+    void updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal);
+
 };
 
 #endif
