@@ -1,16 +1,17 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bBibHighlighter.h"
 #include "c2bSettings.h"
 
-#include <QTextEdit>
+#include <QPalette>
+#include <QTextDocument>
 
 
-c2bBibHighlighter::c2bBibHighlighter(QTextEdit *textEdit) : QSyntaxHighlighter(textEdit)
+c2bBibHighlighter::c2bBibHighlighter(QTextDocument* doc) : QSyntaxHighlighter(doc)
 {
     QPalette p;
     text_color = p.text().color();
@@ -25,16 +26,16 @@ c2bBibHighlighter::c2bBibHighlighter(QTextEdit *textEdit) : QSyntaxHighlighter(t
     rx3 = QRegExp("^%.+$");
 }
 
-
 c2bBibHighlighter::~c2bBibHighlighter()
 {}
 
-void c2bBibHighlighter::highlightBlock(const QString &text)
+
+void c2bBibHighlighter::highlightBlock(const QString& text)
 {
-    int len = text.length();
+    const int len(text.length());
     setFormat(0, len - 1, text_color);
 
-    int pos = 0;
+    int pos(0);
     while (pos >= 0)
     {
         pos = rx0.indexIn(text, pos);
