@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BBIBHIGHLIGHTER_H
@@ -22,12 +22,12 @@ class c2bBibHighlighter : public QSyntaxHighlighter
 {
 
 public:
-    c2bBibHighlighter(QTextEdit *textEdit);
+    c2bBibHighlighter(QTextDocument* doc);
     ~c2bBibHighlighter();
 
 
 protected:
-    virtual void highlightBlock(const QString & text);
+    virtual void highlightBlock(const QString& text);
 
 
 private:
