@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BBIBPREPARSERLOG_H
@@ -13,7 +13,6 @@
 
 
 class QCheckBox;
-class QProcess;
 
 
 class c2bBibPreparserLog : public QDialog
@@ -22,15 +21,14 @@ class c2bBibPreparserLog : public QDialog
     Q_OBJECT
 
 public:
-    c2bBibPreparserLog(QWidget* parent = 0);
+    c2bBibPreparserLog(QWidget* parentw = 0);
     ~c2bBibPreparserLog();
 
     void append(const QString& ms);
-    void readLog(QProcess *ep);
 
 
 public slots:
-    void closeEvent(QCloseEvent* ce);
+    void closeEvent(QCloseEvent* qevent);
     void show();
 
 
