@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bClipboard.h"
@@ -12,7 +12,7 @@
 #include <QApplication>
 
 
-c2bClipboard::c2bClipboard(QObject* parent) : QObject(parent)
+c2bClipboard::c2bClipboard(QObject* parento) : QObject(parento)
 {
     // Connecting clipboard
     cb = QApplication::clipboard();
@@ -28,6 +28,7 @@ c2bClipboard::c2bClipboard(QObject* parent) : QObject(parent)
     interval = 1000;
     // Uncomment the 4 timer-related lines if clipboard appears unresponsive
     // and you cannot compile with cbpoll option
+    timer = 0;
     //     timer = new QTimer( this );
     //     connect(timer, SIGNAL(timeout() ), this, SLOT(checkData()));
 
