@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPBOARD_H
@@ -29,7 +29,7 @@ class c2bClipboard : public QObject
 {
     Q_OBJECT
 public:
-    c2bClipboard(QObject* parent = 0);
+    c2bClipboard(QObject* parento = 0);
     ~c2bClipboard();
 
     const QString text();
