@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bComboBox.h"
@@ -12,7 +12,7 @@
 #include <QMenu>
 
 
-c2bComboBox::c2bComboBox(QWidget* parent) : QComboBox(parent)
+c2bComboBox::c2bComboBox(QWidget* parentw) : QComboBox(parentw)
 {}
 
 c2bComboBox::~c2bComboBox()
