@@ -1,11 +1,11 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
-#ifndef F_COMBOBOX_H
-#define F_COMBOBOX_H
+#ifndef C2BCOMBOBOX_H
+#define C2BCOMBOBOX_H
 
 #include <QComboBox>
 
@@ -16,9 +16,10 @@ class c2bComboBox : public QComboBox
     Q_OBJECT
 
 public:
-    c2bComboBox(QWidget* parent = 0);
+    c2bComboBox(QWidget* parentw = 0);
     ~c2bComboBox();
 
+
 protected:
     virtual void contextMenuEvent(QContextMenuEvent * e);
 
