@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCONFIGURE_H
@@ -22,9 +22,11 @@ class c2bConfigure : public QDialog
     Q_OBJECT
 
 public:
-    c2bConfigure(QWidget* parent = 0);
+    c2bConfigure(QWidget* parentw = 0);
     ~c2bConfigure();
 
+    void setPage(int index);
+
 
 protected slots:
     void FindReplaceDialog_Delete();
@@ -36,31 +38,34 @@ protected slots:
     void changePage(QListWidgetItem* current, QListWidgetItem* previous);
     void comboFamilyChanged(const QString& family);
     void comboSizeChanged(const QString& pt);
-    void fontSelection();
-    void getBibSearcherPdf2TextDir();
+    void getAnnoteCssFile();
+    void getBibSearcherPdf2TextBin();
     void getBrowserCssFile();
     void getCacheDirectory();
-    void getExifToolDir();
+    void getExifToolBin();
     void getFmClientCopyBin();
     void getFmClientMoveBin();
-    void getFmClientOpenBin();
     void getJournalFile();
     void getNetworkFile();
     void getPdfDirectory();
-    void getPdfImportPdf2TextDir();
-    void getPostprocessBibTeXDir();
-    void getPreparserDir();
+    void getPdfImportPdf2TextBin();
+    void getPostprocessBibTeXBin();
+    void getPreparserBin();
     void getRegularExpressionFile();
+    void getjsMathDirectory();
     void help();
     void updateFindReplaceInputButtons();
 
 
 private:
-    QFont font;
+    QFont c2bMonoFont;
+    QFont selectedFont(QFontComboBox* fc, QComboBox* sc) const;
     Ui::c2bConfigure ui;
-    bool event(QEvent* event);
+    bool event(QEvent* qevent);
     c2bColors colors;
     c2bSettings* settings;
+    void fontSelection(const QFont& f, QFontComboBox* fc, QComboBox* sc);
+    void populateFontCombos();
 
 };
 
