@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bEditor.h"
@@ -19,8 +19,11 @@
 #include "c2bTextBrowser.h"
 #include "c2bTextEdit.h"
 #include "c2bUpdateMetadata.h"
+#include "c2bUtils.h"
 #include "findDialog.h"
 
+#include <bibSearcher.h>
+
 #include <QCloseEvent>
 #include <QDir>
 #include <QDockWidget>
@@ -37,7 +40,7 @@
     The cb2Bib contains a practical editor suitable to manipulate the files
     related to a cb2Bib session. Abbreviations, bookmarks, regular expressions,
     and BibTeX are readily available. On BibTeX mode, the editor contains a
-    Reference List to easy file navigation and to extend the editor
+    Reference List to ease file navigation, and to extend the editor
     functionality. The BibTeX editor can optionally be turned to a reference
     browser.
 
@@ -93,9 +96,9 @@ editorbookmark=Application Description|/opt/kde3/bin/kile|Alt+K|/usr/share/icons
     BibTeX references and the actual metadata (often due to HTML tags or other
     illegal characters in BibTeX), or that the writing to the document format
     is not implemented. Note that this process will update all documents
-    referenced in the BibTeX file. <b>While this process is save, it implies
-    writing into the documents.</b> Therefore take the usual safety measures
-    and backup your data. See also \ref metadata_write.
+    referenced in the BibTeX file. <b>While this process is safe, it implies
+    writing into the documents.</b> Therefore take the usual measures and
+    backup your data. See also \ref metadata_write.
 
 
     <p>&nbsp;</p>
@@ -139,8 +142,7 @@ summary="Summary table of Right-Click Menu Functionality">
 <center><table cellpadding="4" cellspacing="2" border="1"
 summary="Summary table of References Right-Click Menu Functionality">
 <tr> <th valign="top">Keys</th> <th valign="top">Action</th></tr>
-<tr> <td valign="top">Alt+X</td> <td valign="top">Cite Selected Entries</td></tr>
-<tr> <td valign="top">Alt+C</td> <td valign="top">Cite to Clipboard</td></tr>
+<tr> <td valign="top">Alt+C</td> <td valign="top">Cite Selected Entries</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Open Document File</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Browse by DOI</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Web Search by Authors</td></tr>
@@ -158,8 +160,7 @@ summary="Summary table of References Right-Click Menu Functionality">
 <center><table cellpadding="4" cellspacing="2" border="1"
 summary="Summary table of Browser Right-Click Menu Functionality">
 <tr> <th valign="top">Keys</th> <th valign="top">Action</th></tr>
-<tr> <td valign="top">Alt+X</td> <td valign="top">Cite Selected Entries</td></tr>
-<tr> <td valign="top">Alt+C</td> <td valign="top">Cite to Clipboard</td></tr>
+<tr> <td valign="top">Alt+C</td> <td valign="top">Cite Selected Entries</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Local Search for selected text</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Web Search for selected text</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Web Search Settings</td></tr>
@@ -209,28 +210,28 @@ summary="Summary table of Additional Functionality">
 */
 
 
-c2bEditor::c2bEditor(const QString& file, const QString& mode, QWidget* main, QWidget* parent) : QMainWindow(parent)
+c2bEditor::c2bEditor(const QString& file, const QString& mode, QWidget* main, QWidget* parentw) : QMainWindow(parentw)
 {
-    EFile = file;
-    EditorMode = mode;
-    c2bMain = main;
-    bibSearcher = 0;
+    _editor_fn = QDir::toNativeSeparators(file);
+    _editor_mode = mode;
+    _c2b_mainP = main;
+    _searcherP = 0;
     initEditor();
 }
 
-c2bEditor::c2bEditor(const QString& file, c2bBibSearcher* searcher, QWidget* main, QWidget* parent) : QMainWindow(parent)
+c2bEditor::c2bEditor(const QString& file, bibSearcher* searcher, QWidget* main, QWidget* parentw) : QMainWindow(parentw)
 {
-    EFile = file;
-    EditorMode = "BibTeX";
-    c2bMain = main;
-    bibSearcher = searcher;
+    _editor_fn = QDir::toNativeSeparators(file);
+    _editor_mode = "BibTeX";
+    _c2b_mainP = main;
+    _searcherP = searcher;
     initEditor();
 }
 
 c2bEditor::~c2bEditor()
 {
-    if (Browser)
-        settings->setValue("c2bEditor/BrowserFontPointSize", Browser->font().pointSize());
+    if (_browserP)
+        _settingsP->setValue("c2bEditor/BrowserFontPointSize", _browserP->font().pointSize());
 }
 
 
@@ -239,51 +240,61 @@ void c2bEditor::initEditor()
     ui.setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
 
-    settings = c2bSettingsP;
-    if (EditorMode == "BibTeX")
-        bp = c2b::bibParser();
+    _settingsP = c2bSettingsP;
+    if (_editor_mode == "BibTeX")
+        _bpP = c2b::bibParser();
     else
-        bp = 0;
-    Browser = 0;
-    Editor = new c2bTextEdit(this);
-    RList = 0;
-    stackedWidget = new QStackedWidget(this);
-    setCentralWidget(stackedWidget);
-    stackedWidget->addWidget(Editor);
-    textFinder = new findDialog(this);
-    lineLabel = new QLabel();
-    lineLabel->setText(tr(" Line: 1 Col: 1 "));
-    lineLabel->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
-    lineLabel->setFrameStyle(QFrame::NoFrame);
-    lineLabel->setLineWidth(1);
-    lineLabel->setFixedHeight(lineLabel->fontMetrics().height());
-    statusBar()->addWidget(lineLabel, 1);
-    connect(Editor, SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
-    overwriteLabel = new QLabel();
-    overwriteLabel->setText(tr(" INS "));
-    overwriteLabel->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
-    overwriteLabel->setFrameStyle(QFrame::NoFrame);
-    overwriteLabel->setLineWidth(1);
-    overwriteLabel->setFixedHeight(overwriteLabel->fontMetrics().height());
-    statusBar()->addWidget(overwriteLabel);
-    Editor->setOverwriteMode(false);
-    connect(Editor, SIGNAL(overwriteModeChanged()), this, SLOT(overwriteModeChanged()));
+        _bpP = 0;
+    _browserP = 0;
+    _editorP = new c2bTextEdit(this);
+    _referencesP = 0;
+    _stackedWidgetP = new QStackedWidget(this);
+    setCentralWidget(_stackedWidgetP);
+    _stackedWidgetP->addWidget(_editorP);
+    _textFinderP = new findDialog(this);
+    _lineLabelP = new QLabel();
+    _lineLabelP->setText(tr(" Line: 1 Col: 1 "));
+    _lineLabelP->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
+    _lineLabelP->setFrameStyle(QFrame::NoFrame);
+    _lineLabelP->setLineWidth(1);
+    _lineLabelP->setFixedHeight(_lineLabelP->fontMetrics().height());
+    statusBar()->addWidget(_lineLabelP, 1);
+    connect(_editorP, SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
+    _overwriteLabelP = new QLabel();
+    _overwriteLabelP->setText(tr(" INS "));
+    _overwriteLabelP->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
+    _overwriteLabelP->setFrameStyle(QFrame::NoFrame);
+    _overwriteLabelP->setLineWidth(1);
+    _overwriteLabelP->setFixedHeight(_overwriteLabelP->fontMetrics().height());
+    statusBar()->addWidget(_overwriteLabelP);
+    _editorP->setOverwriteMode(false);
+    connect(_editorP, SIGNAL(overwriteModeChanged()), this, SLOT(overwriteModeChanged()));
     connect(ui.fileCloseAction, SIGNAL(triggered()), this, SLOT(close()));
     connect(ui.fileExecAction, SIGNAL(triggered()), this, SLOT(saveAndExecute()));
-    connect(ui.fileExitAction, SIGNAL(triggered()), qApp, SLOT(closeAllWindows()));
+    connect(ui.fileExitAction, SIGNAL(triggered()), c2b::instance(), SLOT(exitRequested()));
     connect(ui.fileSaveAction, SIGNAL(triggered()), this, SLOT(fileSave()));
     connect(ui.fileSaveAsAction, SIGNAL(triggered()), this, SLOT(fileSaveAs()));
     connect(ui.helpEditorAction, SIGNAL(triggered()), this, SLOT(helpEditor()));
     connect(ui.helpCb2BibAction, SIGNAL(triggered()), this, SLOT(helpCb2Bib()));
     connect(ui.viewCb2BibAction, SIGNAL(triggered()), this, SLOT(viewCb2Bib()));
 
+    // Standard shortcuts
+    ui.fileCloseAction->setShortcut(QKeySequence(QKeySequence::Close));
+    ui.fileOpenAction->setShortcut(QKeySequence(QKeySequence::Open));
+    ui.fileSaveAction->setShortcut(QKeySequence(QKeySequence::Save));
+#if QT_VERSION >= 0x040500
+    ui.fileSaveAsAction->setShortcut(QKeySequence(QKeySequence::SaveAs));
+#endif
+    ui.helpEditorAction->setShortcut(QKeySequence(QKeySequence::HelpContents));
+    ui.viewZoomInAction->setShortcut(QKeySequence(QKeySequence::ZoomIn));
+    ui.viewZoomOutAction->setShortcut(QKeySequence(QKeySequence::ZoomOut));
+
     // Editor Settings
-    resize(settings->value("c2bEditor/size", size()).toSize());
+    resize(_settingsP->value("c2bEditor/size", size()).toSize());
     ui.menuView->addAction(ui.toolBar->toggleViewAction());
-    ui.setLyxPipeAction->setVisible(false);
-    Editor->setFont(settings->c2bMonoFont);
-    connect(ui.settingsCb2BibAction, SIGNAL(triggered()), c2b::instance(), SLOT(Configure()));
-    connect(settings, SIGNAL(newSettings()), this, SLOT(loadSettings()));
+    ui.setLyXPipeAction->setVisible(false);
+    _editorP->setFont(_settingsP->c2bMonoFont);
+    connect(ui.settingsCb2BibAction, SIGNAL(triggered()), c2b::instance(), SLOT(configure()));
 
     // Bookmarks
     bookmarkPlugin* bookmarks = new bookmarkPlugin(this);
@@ -294,103 +305,103 @@ void c2bEditor::initEditor()
     load();
     setEditorMode();
     importActions();
-    connect(Editor->document(), SIGNAL(contentsChange(int, int, int)), this, SLOT(isModified(int, int, int)));
+    connect(_editorP->document(), SIGNAL(contentsChange(int, int, int)), this, SLOT(isModified(int, int, int)));
     connect(c2b::instance(), SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
 }
 
 void c2bEditor::setEditorMode()
 {
-    if (EditorMode == "RegExp")
+    if (_editor_mode == "RegExp")
     {
-        sH = new c2bREHighlighter(Editor);
+        _shP = new c2bREHighlighter(_editorP->document());
         ui.fileExecAction->setText(tr("Restart Recognition"));
         ui.fileExecAction->setStatusTip(tr("Restart Recognition"));
         ui.fileExecAction->setShortcut(tr("Alt+R"));
         connect(this, SIGNAL(execute()), this, SIGNAL(restartEngine()));
-        ui.toolBar->setVisible(settings->value("c2bEditor/ToolBar", true).toBool());
+        ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
     }
-    else if (EditorMode == "NetQInfo")
+    else if (_editor_mode == "NetQInfo")
     {
-        sH = new c2bREHighlighter(Editor);
+        _shP = new c2bREHighlighter(_editorP->document());
         ui.fileExecAction->setText(tr("Restart Network Query"));
         ui.fileExecAction->setStatusTip(tr("Restart Network Query"));
         ui.fileExecAction->setShortcut(tr("Alt+N"));
         connect(this, SIGNAL(execute()), this, SIGNAL(restartQuery()));
-        ui.toolBar->setVisible(settings->value("c2bEditor/ToolBar", true).toBool());
+        ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
     }
-    else if (EditorMode == "JAbbrev")
+    else if (_editor_mode == "JAbbrev")
     {
         ui.fileExecAction->setVisible(false);
-        ui.toolBar->setVisible(settings->value("c2bEditor/ToolBar", true).toBool());
+        ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
     }
-    else if (EditorMode == "BibTeX")
+    else if (_editor_mode == "BibTeX")
     {
         // Editor
-        sH = new c2bBibHighlighter(Editor);
+        _shP = new c2bBibHighlighter(_editorP->document());
         ui.fileOpenAction->setVisible(true);
         connect(ui.fileOpenAction, SIGNAL(triggered()), this, SLOT(fileOpen()));
-        Editor->setBibTeXActions();
-        connect(Editor->pasteCurrentBibTeXAction, SIGNAL(triggered()), this, SLOT(pasteCurrentBibTeX()));
-        connect(Editor->journalsToFullAction, SIGNAL(triggered()), this, SLOT(journalsToFull()));
-        connect(Editor->journalsToAbbreviatedAction, SIGNAL(triggered()), this, SLOT(journalsToAbbreviated()));
-        connect(Editor->updateMetadataAction, SIGNAL(triggered()), this, SLOT(updateMetadata()));
-        connect(c2bMain, SIGNAL(addedBibToFile(const QString&)), this, SLOT(reload(const QString&)));
+        _editorP->setBibTeXActions();
+        connect(_editorP->pasteCurrentBibTeXAction, SIGNAL(triggered()), this, SLOT(pasteCurrentBibTeX()));
+        connect(_editorP->journalsToFullAction, SIGNAL(triggered()), this, SLOT(journalsToFull()));
+        connect(_editorP->journalsToAbbreviatedAction, SIGNAL(triggered()), this, SLOT(journalsToAbbreviated()));
+        connect(_editorP->updateMetadataAction, SIGNAL(triggered()), this, SLOT(updateMetadata()));
+        connect(_c2b_mainP, SIGNAL(addedBibToFile(const QString&)), this, SLOT(reload(const QString&)));
         ui.fileExecAction->setText(tr("Save and Postprocess"));
         ui.fileExecAction->setStatusTip(tr("Save and Postprocess"));
         ui.fileExecAction->setShortcut(tr("Alt+P"));
         connect(this, SIGNAL(execute()), this, SLOT(postProcess()));
 
         // Browser
-        Browser = new c2bTextBrowser(this);
-        Browser->setFont(QFont(QFont().family(), settings->value("c2bEditor/BrowserFontPointSize", QFont().pointSize()).toInt()));
-        stackedWidget->addWidget(Browser);
+        _browserP = new c2bTextBrowser(this);
+        _browserP->setFont(QFont(QFont().family(), _settingsP->value("c2bEditor/BrowserFontPointSize", QFont().pointSize()).toInt()));
+        _stackedWidgetP->addWidget(_browserP);
         ui.viewEditorModeAction->setVisible(true);
         connect(ui.viewEditorModeAction, SIGNAL(triggered(bool)), this, SLOT(setViewMode(bool)));
-        connect(ui.viewZoomInAction, SIGNAL(triggered()), Browser, SLOT(zoomIn()));
-        connect(ui.viewZoomOutAction, SIGNAL(triggered()), Browser, SLOT(zoomOut()));
+        connect(ui.viewZoomInAction, SIGNAL(triggered()), _browserP, SLOT(zoomIn()));
+        connect(ui.viewZoomOutAction, SIGNAL(triggered()), _browserP, SLOT(zoomOut()));
 
         // Reference List
         createReferenceList();
-        RList->loadList(Editor->toPlainText(), bibSearcher);
-        bool edit_mode = false;
-        if (bibSearcher)
+        _referencesP->loadList(_editorP->toPlainText(), _searcherP);
+        bool edit_mode(false);
+        if (_searcherP)
         {
-            edit_mode = (bibSearcher->hitCount() == 0 && bibSearcher->errorCount() > 0);
-            connect(RList, SIGNAL(openFile(const QString&)), this, SIGNAL(openFile(const QString&)));
+            edit_mode = (_searcherP->hitsCount() == 0 && _searcherP->errorsCount() > 0);
+            connect(_referencesP, SIGNAL(openFile(const QString&)), this, SIGNAL(openFile(const QString&)));
         }
-        if (!edit_reference_at_position.isEmpty())
+        if (!_edit_reference_at_position.isEmpty())
         {
             edit_mode = true;
-            RList->goToReference(edit_reference_at_position.toInt());
+            _referencesP->goToReference(_edit_reference_at_position.toInt());
         }
         ui.viewEditorModeAction->setChecked(edit_mode);
         setViewMode(edit_mode);
-        ui.setLyxPipeAction->setVisible(true);
+        ui.setLyXPipeAction->setVisible(true);
 
         // Export entries
         ui.fileExportEntriesAction->setVisible(true);
         connect(ui.fileExportEntriesAction, SIGNAL(triggered()), this, SLOT(exportEntries()));
-        connect(RList, SIGNAL(hasSelectedItems(bool)), ui.fileExportEntriesAction, SLOT(setEnabled(bool)));
+        connect(_referencesP, SIGNAL(hasSelectedItems(bool)), ui.fileExportEntriesAction, SLOT(setEnabled(bool)));
     }
     else
-        c2bUtils::debug(tr("c2bEditor::setEditorMode: '%1' invalid Editor Mode.").arg(EditorMode));
+        c2bUtils::debug(tr("c2bEditor::setEditorMode: '%1' invalid Editor Mode.").arg(_editor_mode));
 }
 
 void c2bEditor::importActions()
 {
-    QList<QAction*> acts = textFinder->actions();
+    QList<QAction*> acts = _textFinderP->actions();
     for (int i = 0; i < acts.count(); ++i)
         ui.menuEdit->addAction(acts.at(i));
-    acts = Editor->actions();
+    acts = _editorP->actions();
     for (int i = 0; i < acts.count(); ++i)
         ui.menuEdit->addAction(acts.at(i));
-    if (Browser)
+    if (_browserP)
     {
         ui.menuEdit->addSeparator();
-        acts = Browser->actions();
+        acts = _browserP->actions();
         for (int i = 0; i < acts.count(); ++i)
             ui.menuEdit->addAction(acts.at(i));
     }
@@ -398,37 +409,40 @@ void c2bEditor::importActions()
 
 void c2bEditor::createReferenceList()
 {
-    dwRList = new QDockWidget(this);
-    dwRList->setObjectName("dwRList");
-    RList = new c2bReferenceList(Editor, Browser, dwRList);
-    addDockWidget(Qt::BottomDockWidgetArea, dwRList);
-    dwRList->setWidget(RList);
-    dwRList->setWindowTitle("Reference List");
-    QByteArray state = settings->value("c2bEditor/state").toByteArray();
+    _dockWidgetP = new QDockWidget(this);
+    _dockWidgetP->setObjectName("dwRList");
+    _referencesP = new c2bReferenceList(_editorP, _browserP, _dockWidgetP);
+    addDockWidget(Qt::BottomDockWidgetArea, _dockWidgetP);
+    _dockWidgetP->setWidget(_referencesP);
+    _dockWidgetP->setWindowTitle("Reference List");
+    QByteArray state = _settingsP->value("c2bEditor/state").toByteArray();
     restoreState(state);
-    ui.menuView->addAction(dwRList->toggleViewAction());
+    ui.menuView->addAction(_dockWidgetP->toggleViewAction());
     // State contains toolBar info, too, but it can be changed from non BibTeX editors
     // State can not be used for non BibTeX editors. They don't have referenceList.
-    ui.toolBar->setVisible(settings->value("c2bEditor/ToolBar", true).toBool());
-    connect(ui.setLyxPipeAction, SIGNAL(triggered()), RList, SLOT(setLyxPipe()));
+    ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
+    connect(ui.setLyXPipeAction, SIGNAL(triggered()), _referencesP, SLOT(setLyXPipe()));
 }
 
-void c2bEditor::closeEvent(QCloseEvent *ce)
+void c2bEditor::closeEvent(QCloseEvent* qevent)
 {
     if (closeEditor())
-        ce->accept();
+        qevent->accept();
     else
-        ce->ignore();
+        qevent->ignore();
 }
 
 bool c2bEditor::closeEditor()
 {
-    if (ui.fileSaveAction->isEnabled())
+    // Use _is_modified_by_user to check if closing is possible. This way,
+    // no question is asked to exit browsing of search results. Do not use
+    // here ui.fileSaveAction->isEnabled().
+    if (_is_modified_by_user)
     {
-        int button = QMessageBox::information(this, tr("Information - cb2Bib"),
-                                              tr("The document has been modified.\nDo you want to save the changes?"),
-                                              QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel,
-                                              QMessageBox::Save);
+        const int button(QMessageBox::information(this, tr("Information - cb2Bib"),
+                         tr("The document has been modified.\nDo you want to save the changes?"),
+                         QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel,
+                         QMessageBox::Save));
         if (button == QMessageBox::Save)
         {
             if (!fileSave())
@@ -437,10 +451,10 @@ bool c2bEditor::closeEditor()
         else if (button == QMessageBox::Cancel)
             return false;
     }
-    settings->setValue("c2bEditor/size", size());
-    if (EditorMode == "BibTeX")
-        settings->setValue("c2bEditor/state", saveState());
-    settings->setValue("c2bEditor/ToolBar", !ui.toolBar->isHidden());
+    _settingsP->setValue("c2bEditor/size", size());
+    if (_editor_mode == "BibTeX")
+        _settingsP->setValue("c2bEditor/state", saveState());
+    _settingsP->setValue("c2bEditor/ToolBar", !ui.toolBar->isHidden());
     return true;
 }
 
@@ -450,60 +464,64 @@ void c2bEditor::isModified(int position, int charsRemoved, int charsAdded)
         return;
     ui.fileSaveAction->setEnabled(true);
     setWindowModified(true);
+    _is_modified_by_user = true;
 }
 
 void c2bEditor::fileOpen()
 {
-    if (EditorMode == "BibTeX")
+    if (_editor_mode == "BibTeX")
     {
-        QString fileName = c2bFileDialog::getOpenFileName(this, "Select a BibTeX filename", EFile, "BibTeX (*.bib)");
-        if (!fileName.isEmpty())
-            emit openFile(fileName);
+        const QString filename(c2bFileDialog::getOpenFilename(this, "Select a BibTeX filename", _editor_fn, "BibTeX (*.bib)"));
+        if (!filename.isEmpty())
+            emit openFile(filename);
     }
 }
 
 bool c2bEditor::fileSave()
 {
-    if (EFile.contains("unnamed_"))
+    if (_editor_fn.contains("unnamed_"))
         return fileSaveAs();
-    QFile file(EFile);
+    QFile file(_editor_fn);
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
     {
         QMessageBox::warning(this, tr("Warning - cb2Bib"),
                              tr("Unable to open the file %1 for writing.\nError: '%2'.").
-                             arg(EFile).arg(file.errorString()),
+                             arg(_editor_fn).arg(file.errorString()),
                              QMessageBox::Ok);
         return false;
     }
     QTextStream stream(&file);
     stream.setCodec("UTF-8");
     stream.setAutoDetectUnicode(true);
-    stream << Editor->toPlainText();
+    stream << _editorP->toPlainText();
     ui.fileSaveAction->setEnabled(false);
-    Editor->document()->setModified(false);
+    _editorP->document()->setModified(false);
     setWindowModified(false);
+    _is_modified_by_user = false;
     return true;
 }
 
 bool c2bEditor::fileSaveAs()
 {
-    QString fileName;
-    if (EditorMode == "BibTeX")
-        fileName = c2bFileDialog::getSaveFileName(this, "", EFile, "BibTeX (*.bib);;All (*)");
+    QString filename;
+    if (_editor_mode == "BibTeX")
+        filename = c2bFileDialog::getSaveFilename(this, "", _editor_fn, "BibTeX (*.bib);;All (*)");
     else
-        fileName = c2bFileDialog::getSaveFileName(this, "", EFile, "Text (*.txt);;All (*)");
-    if (fileName.isEmpty() || fileName.contains("unnamed_"))
+        filename = c2bFileDialog::getSaveFilename(this, "", _editor_fn, "Text (*.txt);;All (*)");
+    if (filename.isEmpty() || filename.contains("unnamed_"))
         return false;
-    QString old_name = EFile;
-    EFile = fileName;
-    setWindowTitle(tr("%1[*] - cb2Bib").arg(EFile));
-    Editor->setEditFileName(EFile);
-    emit editFileRenamed(old_name, EFile);
+    const QString old_name(_editor_fn);
+    _editor_fn = filename;
+    setWindowTitle(tr("%1[*] - cb2Bib").arg(_editor_fn));
+    _editorP->setEditorFilename(_editor_fn);
+    emit editFileRenamed(old_name, _editor_fn);
     return fileSave();
 }
 
 void c2bEditor::saveAndExecute()
 {
+    // Use ui.fileSaveAction->isEnabled() instead of _is_modified_by_user.
+    // If browsing search results there is no file on disk.
     if (ui.fileSaveAction->isEnabled())
     {
         if (fileSave())
@@ -515,9 +533,9 @@ void c2bEditor::saveAndExecute()
 
 void c2bEditor::load()
 {
-    bool modified_flag = false;
-    QFileInfo fi(EFile);
-    if (EFile.isEmpty() || fi.isDir())  // Set an appropriate working name
+    bool modified_flag(false);
+    QFileInfo fi(_editor_fn);
+    if (_editor_fn.isEmpty() || fi.isDir())  // Set an appropriate working name
     {
         QStringList unamedList;
         foreach(QWidget* widget, QApplication::topLevelWidgets())
@@ -525,29 +543,29 @@ void c2bEditor::load()
             if (widget->inherits("c2bEditor"))
                 unamedList.append(widget->objectName());
         }
-        int i = 1;
+        int i(1);
         while (unamedList.indexOf(QRegExp(QString(".*unnamed_%1.bib").arg(i))) > -1) ++i;
-        EFile = QDir::cleanPath(EFile + QDir::separator() + QString("unnamed_%1.bib").arg(i));
-        if (bibSearcher)
+        _editor_fn = QDir::toNativeSeparators(QDir::cleanPath(_editor_fn + QDir::separator() + QString("unnamed_%1.bib").arg(i)));
+        if (_searcherP)
         {
-            Editor->setPlainText(bibSearcher->logString + bibSearcher->hitString);
+            _editorP->setPlainText(_searcherP->logString() + _searcherP->hitsString());
             modified_flag = true;
         }
     }
     else
     {
         QRegExp edit_ref_id(":(\\d+)$");
-        if (EFile.contains(edit_ref_id))
+        if (edit_ref_id.indexIn(_editor_fn) > -1)
         {
-            edit_reference_at_position = edit_ref_id.cap(1);
-            EFile.remove(edit_ref_id);
+            _edit_reference_at_position = edit_ref_id.cap(1);
+            _editor_fn.remove(edit_ref_id);
         }
-        QFile file(EFile);
+        QFile file(_editor_fn);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
         {
-            QMessageBox::warning(c2bMain,
+            QMessageBox::warning(_c2b_mainP,
                                  tr("Warning - cb2Bib"), tr("Unable to open the file %1 for reading.\nError: '%2'.").
-                                 arg(EFile).arg(file.errorString()),
+                                 arg(_editor_fn).arg(file.errorString()),
                                  QMessageBox::Ok);
         }
         else
@@ -555,21 +573,22 @@ void c2bEditor::load()
             QTextStream stream(&file);
             stream.setCodec("UTF-8");
             stream.setAutoDetectUnicode(true);
-            Editor->setPlainText(stream.readAll());
+            _editorP->setPlainText(stream.readAll());
         }
     }
-    setWindowTitle(tr("%1[*] - cb2Bib").arg(EFile));
-    Editor->setEditFileName(EFile);
+    setWindowTitle(tr("%1[*] - cb2Bib").arg(_editor_fn));
+    _editorP->setEditorFilename(_editor_fn);
     ui.fileSaveAction->setEnabled(modified_flag);
-    Editor->document()->setModified(modified_flag);
+    _editorP->document()->setModified(modified_flag);
     setWindowModified(modified_flag);
+    _is_modified_by_user = false;
 }
 
-void c2bEditor::reload(const QString& f)
+void c2bEditor::reload(const QString& fn)
 {
     // This function must be called ONLY in BibTeX mode
     // Pointers are undefined otherwise
-    if (EditorMode != "BibTeX" || EFile != f)
+    if (_editor_mode != "BibTeX" || _editor_fn != fn)
         return;
 
     if (ui.fileSaveAction->isEnabled())
@@ -584,78 +603,80 @@ void c2bEditor::reload(const QString& f)
                           "To preserve local changes press Save and insert again the last reference.\n\n"
                           "Do you want to save the changes?"));
         msgBox.setIcon(QMessageBox::Information);
-        int button = msgBox.exec();
+        const int button(msgBox.exec());
         if (button == QMessageBox::Save)
         {
             fileSave();
-            RList->refreshList();
+            _referencesP->refreshList();
             return;
         }
         else if (button == QMessageBox::Cancel)
             return;
     }
     load();
-    RList->refreshList();
-    QTextCursor cur = Editor->textCursor();
+    _referencesP->refreshList();
+    QTextCursor cur = _editorP->textCursor();
     cur.movePosition(QTextCursor::End, QTextCursor::MoveAnchor);
-    Editor->setTextCursor(cur);
-    Editor->ensureCursorVisible();
+    _editorP->setTextCursor(cur);
+    _editorP->ensureCursorVisible();
 }
 
 void c2bEditor::exportEntries()
 {
-    QStringList keys = RList->selectedKeys();
+    const QStringList keys(_referencesP->selectedKeys());
     if (keys.count() == 0)
         return;
-    c2bExportDialog ed(EFile, keys, this);
+    c2bExportDialog ed(_editor_fn, _editorP->toPlainText(), keys, this);
     if (ed.exec())
         emit openFile(ed.exportFilename());
 }
 
 void c2bEditor::pasteCurrentBibTeX()
 {
-    Editor->insertPlainText(bp->makeBib(false));
+    _editorP->insertPlainText(_bpP->toBibTeX(false));
 }
 
 void c2bEditor::journalsToFull()
 {
-    QString text = bp->setJournalsToFull(Editor->toPlainText());
-    Editor->updatePlainText(text);
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    const QString text(_bpP->setJournalsToFull(_editorP->toPlainText()));
+    _editorP->updatePlainText(text);
+    QApplication::restoreOverrideCursor();
 }
 
 void c2bEditor::journalsToAbbreviated()
 {
-    QString text = bp->setJournalsToAbbreviated(Editor->toPlainText());
-    Editor->updatePlainText(text);
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    const QString text(_bpP->setJournalsToAbbreviated(_editorP->toPlainText()));
+    _editorP->updatePlainText(text);
+    QApplication::restoreOverrideCursor();
 }
 
 void c2bEditor::updateMetadata()
 {
     c2bUpdateMetadata um(this);
-    um.update(EFile, Editor->toPlainText());
+    um.update(_editor_fn, _editorP->toPlainText());
 }
 
 void c2bEditor::postProcess()
 {
-    c2bPostprocess* ppBib = new c2bPostprocess(EFile, this);
+    c2bPostprocess* ppBib = new c2bPostprocess(_editor_fn, this);
     ppBib->show();
 }
 
 void c2bEditor::helpEditor()
 {
-    c2b::displayHelp("http://www.molspaces.com/d_cb2bib-c2beditor.php");
+    c2bUtils::displayHelp("http://www.molspaces.com/d_cb2bib-c2beditor.php");
 }
 
 void c2bEditor::helpCb2Bib()
 {
-    c2b::displayHelp("http://www.molspaces.com/cb2bib/index.html");
+    c2bUtils::displayHelp("http://www.molspaces.com/cb2bib/index.html");
 }
 
 void c2bEditor::viewCb2Bib()
 {
-    c2bMain->showNormal();
-    c2bMain->raise();
-    c2bMain->activateWindow();
+    c2bUtils::setWidgetOnTop(_c2b_mainP);
 }
 
 void c2bEditor::setViewMode(bool edit_mode)
@@ -663,33 +684,33 @@ void c2bEditor::setViewMode(bool edit_mode)
     QList<QAction*> acts;
     if (edit_mode)
     {
-        textFinder->setEditor(Editor);
-        if (Browser)
+        _textFinderP->setEditor(_editorP);
+        if (_browserP)
         {
-            acts = Browser->actions();
+            acts = _browserP->actions();
             for (int i = 0; i < acts.count(); ++i)
                 acts.at(i)->setVisible(false);
             ui.viewZoomInAction->setVisible(false);
             ui.viewZoomOutAction->setVisible(false);
         }
-        acts = Editor->actions();
+        acts = _editorP->actions();
         for (int i = 0; i < acts.count(); ++i)
             acts.at(i)->setVisible(true);
-        stackedWidget->setCurrentWidget(Editor);
+        _stackedWidgetP->setCurrentWidget(_editorP);
     }
     else
     {
         // Browser defined
-        textFinder->setEditor(Browser);
-        acts = Editor->actions();
+        _textFinderP->setEditor(_browserP);
+        acts = _editorP->actions();
         for (int i = 0; i < acts.count(); ++i)
             acts.at(i)->setVisible(false);
-        acts = Browser->actions();
+        acts = _browserP->actions();
         for (int i = 0; i < acts.count(); ++i)
             acts.at(i)->setVisible(true);
         ui.viewZoomInAction->setVisible(true);
         ui.viewZoomOutAction->setVisible(true);
-        stackedWidget->setCurrentWidget(Browser);
+        _stackedWidgetP->setCurrentWidget(_browserP);
     }
 }
 
@@ -700,34 +721,23 @@ void c2bEditor::showMessage(const QString& ms)
 
 void c2bEditor::cursorPositionChanged()
 {
-    int lineNumber = 0;
-    QTextBlock current = Editor->textCursor().block();
+    int lineNumber(0);
+    QTextBlock current = _editorP->textCursor().block();
     QTextBlock b;
-    for (b = Editor->document()->begin(); b.isValid(); b = b.next())
+    for (b = _editorP->document()->begin(); b.isValid(); b = b.next())
     {
         ++lineNumber;
         if (b == current)
             break;
     }
-    int linePosition = Editor->textCursor().position() - current.position() + 1;
-    lineLabel->setText(tr(" Line: %1 Col: %2 ").arg(lineNumber).arg(linePosition));
+    int linePosition(_editorP->textCursor().position() - current.position() + 1);
+    _lineLabelP->setText(tr(" Line: %1 Col: %2 ").arg(lineNumber).arg(linePosition));
 }
 
 void c2bEditor::overwriteModeChanged()
 {
-    if (Editor->overwriteMode())
-        overwriteLabel->setText(tr(" OVR "));
+    if (_editorP->overwriteMode())
+        _overwriteLabelP->setText(tr(" OVR "));
     else
-        overwriteLabel->setText(tr(" INS "));
-}
-
-QString c2bEditor::editFileName() const
-{
-    return EFile;
-}
-
-void c2bEditor::loadSettings()
-{
-    if (font() != settings->c2bMonoFont)
-        Editor->setFont(settings->c2bMonoFont);
+        _overwriteLabelP->setText(tr(" INS "));
 }
