@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BEXPORT_H
@@ -17,11 +17,12 @@ class c2bExport : public QObject
     Q_OBJECT
 
 public:
-    c2bExport(QObject* parent = 0);
+    c2bExport(QObject* parento = 0);
     ~c2bExport();
 
     struct export_data
     {
+        QString bibtex_contents;
         QString bibtex_fn;
         QString documents_dir;
         QString export_fn;
