@@ -1,27 +1,35 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bExportDialog.h"
 
 #include "c2b.h"
-#include "c2bExport.h"
 #include "c2bFileDialog.h"
 #include "c2bSettings.h"
+#include "c2bUtils.h"
 
 #include <QMessageBox>
 #include <QPushButton>
 
 
-c2bExportDialog::c2bExportDialog(const QString& fn, const QStringList& keys, QWidget* parent) :
-        QDialog(parent), _bibtex_fn(fn), _bibtex_keys(keys)
+c2bExportDialog::c2bExportDialog(const QString& fn, const QString& contents, const QStringList& keys, QWidget* parentw) :
+        QDialog(parentw)
 {
+    _ed.bibtex_fn = fn;
+    if (contents.isEmpty())
+        _ed.bibtex_contents = c2bUtils::fileToString(fn);
+    else
+        _ed.bibtex_contents = contents;
+    _ed.bibtex_keys = keys;
     ui.setupUi(this);
     setWindowTitle(tr("Export Entries - cb2Bib"));
     QPushButton* buttonExport = new QPushButton(tr("Export"));
     ui.buttonBox->addButton(buttonExport, QDialogButtonBox::ActionRole);
+    buttonExport->setAutoDefault(true);
+    buttonExport->setDefault(true);
     connect(buttonExport, SIGNAL(clicked()), this, SLOT(_export()));
 
     settings = c2bSettingsP;
@@ -50,26 +58,23 @@ c2bExportDialog::~c2bExportDialog()
 
 void c2bExportDialog::_export()
 {
-    c2bExport::export_data ed;
-    ed.bibtex_fn = _bibtex_fn;
-    ed.bibtex_keys = _bibtex_keys;
-    ed.copy_documents = ui.CopyDocuments->isChecked();
-    ed.documents_dir = ui.DocumentsDirectory->text();
-    ed.export_fn = ui.ExportFile->text();
-    ed.relative_dir = ui.RelativeDocumentDirectory->isChecked();
+    _ed.copy_documents = ui.CopyDocuments->isChecked();
+    _ed.documents_dir = ui.DocumentsDirectory->text();
+    _ed.export_fn = ui.ExportFile->text();
+    _ed.relative_dir = ui.RelativeDocumentDirectory->isChecked();
 
     // Check files
-    if (QFileInfo(ed.export_fn).exists())
+    if (QFileInfo(_ed.export_fn).exists())
     {
-        int button = QMessageBox::warning(this, tr("Warning - cb2Bib"),
-                                          tr("File %1 already exists.\nDo you want to replace it?").arg(ed.export_fn),
-                                          QMessageBox::Yes | QMessageBox::No);
+        const int button(QMessageBox::warning(this, tr("Warning - cb2Bib"),
+                                              tr("File %1 already exists.\nDo you want to replace it?").arg(_ed.export_fn),
+                                              QMessageBox::Yes | QMessageBox::No));
         if (button == QMessageBox::No)
             return;
     }
-    if (ed.copy_documents)
+    if (_ed.copy_documents)
     {
-        QString ddname = c2bUtils::documentAbsoluteName(ed.relative_dir, ed.export_fn, ed.documents_dir, "") + QDir::separator();
+        const QString ddname(c2bUtils::documentAbsoluteName(_ed.relative_dir, _ed.export_fn, _ed.documents_dir, "") + QDir::separator());
         QDir doc_dir(ddname);
         if (!doc_dir.exists())
             if (!doc_dir.mkpath(ddname))
@@ -79,27 +84,26 @@ void c2bExportDialog::_export()
                 return;
             }
     }
-
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     c2bExport e(this);
-    e.exportEntries(ed);
+    e.exportEntries(_ed);
+    QApplication::restoreOverrideCursor();
     accept();
 }
 
 void c2bExportDialog::getExportFile()
 {
-    QString fn = ui.ExportFile->text();
-    QString new_fn = c2bFileDialog::getFileName(this, tr("Select export filename"), fn, "BibTeX (*.bib)");
+    const QString fn(ui.ExportFile->text());
+    const QString new_fn(c2bFileDialog::getFilename(this, tr("Select export filename"), fn, "BibTeX (*.bib)"));
     if (!new_fn.isEmpty())
         ui.ExportFile->setText(new_fn);
 }
 
 void c2bExportDialog::getDocumentsDirectory()
 {
-    QString dir = c2bUtils::documentAbsoluteName(ui.RelativeDocumentDirectory->isChecked(), ui.ExportFile->text(),
-                  ui.DocumentsDirectory->text(), "doc.txt");
-    if (dir.isEmpty())
-        dir = QDir::homePath();
-    QString new_dir = c2bFileDialog::getExistingDirectory(this, tr("Select documents directory"), dir);
+    const QString dir(c2bUtils::documentAbsoluteName(ui.RelativeDocumentDirectory->isChecked(), ui.ExportFile->text(),
+                      ui.DocumentsDirectory->text(), ""));
+    QString new_dir(c2bFileDialog::getExistingDirectory(this, tr("Select documents directory"), dir));
     if (!new_dir.isEmpty())
     {
         new_dir = c2bUtils::documentDirName(ui.RelativeDocumentDirectory->isChecked(), ui.ExportFile->text(), new_dir);
@@ -109,5 +113,5 @@ void c2bExportDialog::getDocumentsDirectory()
 
 void c2bExportDialog::help()
 {
-    c2b::displayHelp("http://www.molspaces.com/d_cb2bib-c2beditor.php#export_entries");
+    c2bUtils::displayHelp("http://www.molspaces.com/d_cb2bib-c2beditor.php#export_entries");
 }
