@@ -1,12 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BEXPORTDIALOG_H
 #define C2BEXPORTDIALOG_H
 
+#include "c2bExport.h"
+
 #include "ui_c2bExportDialog.h"
 
 #include <QDialog>
@@ -20,7 +22,7 @@ class c2bExportDialog : public QDialog
     Q_OBJECT
 
 public:
-    c2bExportDialog(const QString& fn, const QStringList& keys, QWidget* parent = 0);
+    c2bExportDialog(const QString& fn, const QString& contents, const QStringList& keys, QWidget* parentw = 0);
     ~c2bExportDialog();
 
     inline const QString exportFilename() const
@@ -31,9 +33,8 @@ public:
 
 private:
     Ui::c2bExportDialog ui;
+    c2bExport::export_data _ed;
     c2bSettings* settings;
-    const QString& _bibtex_fn;
-    const QStringList& _bibtex_keys;
 
 
 private slots:
