@@ -1,16 +1,17 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bHighlighter.h"
 #include "c2bSettings.h"
 
-#include <QTextEdit>
+#include <QPalette>
+#include <QTextDocument>
 
 
-c2bHighlighter::c2bHighlighter(QTextEdit* textEdit) : QSyntaxHighlighter(textEdit)
+c2bHighlighter::c2bHighlighter(QTextDocument* doc) : QSyntaxHighlighter(doc)
 {
     QPalette p;
     text_color = p.text().color();
@@ -48,10 +49,10 @@ c2bHighlighter::~c2bHighlighter()
 
 void c2bHighlighter::highlightBlock(const QString& text)
 {
-    int len = text.length();
+    const int len(text.length());
     setFormat(0, len - 1, text_color);
 
-    int pos = 0;
+    int pos(0);
     while (pos >= 0)
     {
         pos = rx0.indexIn(text, pos);
@@ -123,12 +124,12 @@ void c2bHighlighter::highlightBlock(const QString& text)
     }
 
     setCurrentBlockState(0);
-    int startIndexMD = 0;
+    int startIndexMD(0);
     if (previousBlockState() != 1)
-        startIndexMD = text.indexOf(rx_metadata_starts);
+        startIndexMD = rx_metadata_starts.indexIn(text);
     while (startIndexMD >= 0)
     {
-        int endIndex = text.indexOf(rx_metadata_ends, startIndexMD);
+        const int endIndex(rx_metadata_ends.indexIn(text, startIndexMD));
         int extractedLength;
         if (endIndex == -1)
         {
@@ -138,15 +139,15 @@ void c2bHighlighter::highlightBlock(const QString& text)
         else
             extractedLength = endIndex - startIndexMD + rx_metadata_ends.matchedLength();
         setFormat(startIndexMD, extractedLength, c->cb2bib_metadata_color);
-        startIndexMD = text.indexOf(rx_metadata_starts, startIndexMD + extractedLength);
+        startIndexMD = rx_metadata_starts.indexIn(text, startIndexMD + extractedLength);
     }
 
-    int startIndexEx = 0;
+    int startIndexEx(0);
     if (previousBlockState() != 2)
-        startIndexEx = text.indexOf(rx_extracted_starts);
+        startIndexEx = rx_extracted_starts.indexIn(text);
     while (startIndexEx >= 0)
     {
-        int endIndex = text.indexOf(rx_extracted_ends, startIndexEx);
+        const int endIndex(rx_extracted_ends.indexIn(text, startIndexEx));
         int extractedLength;
         if (endIndex == -1)
         {
@@ -156,6 +157,6 @@ void c2bHighlighter::highlightBlock(const QString& text)
         else
             extractedLength = endIndex - startIndexEx + rx_extracted_ends.matchedLength();
         setFormat(startIndexEx, extractedLength, c->cb2bib_unrelevant_color);
-        startIndexEx = text.indexOf(rx_extracted_starts, startIndexEx + extractedLength);
+        startIndexEx = rx_extracted_starts.indexIn(text, startIndexEx + extractedLength);
     }
 }
