@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BNETWORKQUERYINFO_H
@@ -13,7 +13,6 @@
 class QAction;
 class QFileSystemWatcher;
 class c2bBibParser;
-class c2bLineEdit;
 
 
 /**
@@ -25,7 +24,7 @@ class c2bNetworkQueryInfo : public QObject
     Q_OBJECT
 
 public:
-    c2bNetworkQueryInfo(c2bBibParser* bp, QObject* parent = 0);
+    c2bNetworkQueryInfo(QObject* parento = 0);
     ~c2bNetworkQueryInfo();
 
     QList<QAction*> bookmarkActions(const QString& selection);
@@ -34,18 +33,17 @@ public:
 
 
 private:
-    QFileSystemWatcher* fsw;
+    QFileSystemWatcher* _fsw;
     QList<QAction*> BookmarkActionList;
     QString NetworkFile;
     QString _current_selection;
     QStringList BookmarkList;
-    const QHash<QString, c2bLineEdit*>& bibFields;
-    const QStringList& bibFieldList;
+    const c2bBibParser* _bpP;
 
 
 private slots:
-    void actionTriggered();
     void loadSettings();
+    void openBookmark();
     void parseBookmarks();
 
 };
