@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BPDFIMPORT_H
@@ -12,7 +12,6 @@
 
 
 class c2bSettings;
-class QProcess;
 
 class c2bPdfImport : public QDialog
 {
@@ -20,7 +19,7 @@ class c2bPdfImport : public QDialog
     Q_OBJECT
 
 public:
-    c2bPdfImport(QWidget* parent = 0);
+    c2bPdfImport(QWidget* parentw = 0);
     ~c2bPdfImport();
 
     QString processedFile;
@@ -34,16 +33,16 @@ public slots:
 
 
 signals:
-    void fileProcessed(const QString& fileName);
+    void fileProcessed(const QString& filename);
     void saveReferenceRequest();
     void setClipboardDisabled(bool disable);
     void textProcessed(const QString& text);
 
 
 protected:
-    bool event(QEvent* event);
-    void dragEnterEvent(QDragEnterEvent* event);
-    void dropEvent(QDropEvent* event);
+    bool event(QEvent* qevent);
+    void dragEnterEvent(QDragEnterEvent* qevent);
+    void dropEvent(QDropEvent* qevent);
 
 
 private slots:
@@ -56,16 +55,13 @@ private slots:
 
 
 private:
+    QPushButton* buttonProcess;
+    QPushButton* buttonSelectFiles;
+    Ui::c2bPdfImport ui;
     bool c2bAutomaticQuery;
     bool m_aborted;
     c2bSettings* settings;
-    QProcess *pdf2txt;
-    QPushButton* buttonProcess;
-    QPushButton* buttonSelectFiles;
-    QString m_text_file;
-    Ui::c2bPdfImport ui;
-    void addToLog();
-    void processEnded();
+    void processDocument();
 
 };
 
