@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BPOSTPROCESS_H
@@ -20,7 +20,7 @@ class c2bPostprocess : public QDialog
     Q_OBJECT
 
 public:
-    c2bPostprocess(const QString& fn, QWidget* parent = 0);
+    c2bPostprocess(const QString& fn, QWidget* parentw = 0);
     ~c2bPostprocess();
 
 
@@ -36,13 +36,13 @@ protected slots:
 
 
 private:
-    QProcess* ppBibTeX;
-    QPushButton* buttonOpenFile;
+    QProcess* _ppBibTeX;
+    QPushButton* _buttonOpenFile;
     QString PPBIBTEX_ARG;
     QString PPBIBTEX_BIN;
     QString PPBIBTEX_EXT;
-    QString bib;
-    QString out;
+    QString _bib;
+    QString _out;
     Ui::c2bLogWidget ui;
 
 };
