@@ -1,19 +1,19 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bRLWebSearchSettings.h"
 #include "c2bSettings.h"
 
 
-c2bRLWebSearchSettings::c2bRLWebSearchSettings(QWidget* parent) : QDialog(parent)
+c2bRLWebSearchSettings::c2bRLWebSearchSettings(QWidget* parentw) : QDialog(parentw)
 {
     ui.setupUi(this);
     resize(size().width(), 1);
     c2bSettings* settings = c2bSettingsP;
-    QString searchEngine = settings->value("c2bReferenceList/SearchEngine").toString();
+    const QString searchEngine(settings->value("c2bReferenceList/SearchEngine").toString());
     ui.searchEngine->addItem(searchEngine);
     ui.searchEngine->addItem("http://www.google.com/search?ie=UTF-8&q=");
     ui.searchEngine->addItem("http://scholar.google.com/scholar?ie=UTF-8&q=");
