@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BRLWEBSEARCHSETTINGS_H
@@ -17,7 +17,7 @@ class c2bRLWebSearchSettings : public QDialog
     Q_OBJECT
 
 public:
-    c2bRLWebSearchSettings(QWidget* parent = 0);
+    c2bRLWebSearchSettings(QWidget* parentw = 0);
     ~c2bRLWebSearchSettings();
 
 
