@@ -1,58 +1,60 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
- *
- *   The LyX pipe procedure in citeEntry has been adapted from Tellico
- *   (Tellico (C) 2003-2005 by Robby Stephenson)
  ***************************************************************************/
 #include "c2bReferenceList.h"
 
 #include "c2b.h"
-#include "c2bApproximatePattern.h"
 #include "c2bBibParser.h"
-#include "c2bBibSearcher.h"
-#include "c2bFileDialog.h"
+#include "c2bCoreCiter.h"
 #include "c2bRLWebSearchSettings.h"
 #include "c2bSettings.h"
 #include "c2bTextBrowser.h"
 #include "c2bTextEdit.h"
 #include "c2bUtils.h"
 
-#include <QByteArray>
-#include <QClipboard>
-#include <QDir>
+#include <bibSearcher.h>
+
 #include <QHeaderView>
 #include <QMenu>
-#include <QMessageBox>
 #include <QScrollBar>
-#include <QStandardItemModel>
-#include <QTextCursor>
 #include <QTimer>
-#include <QUrl>
-
-// fifo to lyx
-#include <fcntl.h>
-#include <unistd.h>
 
 
-c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget* parent) : QWidget(parent)
+class TreeWidgetItem : public QTreeWidgetItem
+{
+    // Reimplement sorting
+public:
+    TreeWidgetItem(const QStringList& strings) : QTreeWidgetItem(strings) {}
+    bool operator< (const QTreeWidgetItem& other) const
+    {
+        const int sortCol(treeWidget()->sortColumn());
+        const QString str(c2bUtils::toAscii(text(sortCol), c2bUtils::Collation));
+        const QString other_str(c2bUtils::toAscii(other.text(sortCol), c2bUtils::Collation));
+        return str < other_str;
+    }
+};
+
+
+c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget* parentw) : QWidget(parentw)
 {
     ui.setupUi(this);
-    editorPtr = ed;
-    browserPtr = br;
-    settings = c2bSettingsP;
-    settings->setDefaultValue("c2bReferenceList/SearchEngine", "http://www.google.com/search?ie=UTF-8&q=");
-    settings->setDefaultValue("c2bReferenceList/SearchEngineAddQuotes", false);
+    _editorP = ed;
+    _browserP = br;
+    _citerP = new c2bCoreCiter(this);
+    _settingsP = c2bSettingsP;
+    _settingsP->setDefaultValue("c2bReferenceList/SearchEngine", "http://www.google.com/search?ie=UTF-8&q=");
+    _settingsP->setDefaultValue("c2bReferenceList/SearchEngineAddQuotes", false);
     setupFilterBar();
 
-    m_key_index = 0;
-    m_id_index = 1;
-    m_year_index = 2;
-    m_journal_index = 3;
-    m_author_index = 4;
-    m_title_index = 5;
+    _key_index = 0;
+    _id_index = 1;
+    _year_index = 2;
+    _journal_index = 3;
+    _author_index = 4;
+    _title_index = 5;
     QStringList header;
     header.append(tr("Key"));
     header.append(tr("ID"));
@@ -60,23 +62,16 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     header.append(tr("Journal"));
     header.append(tr("Authors"));
     header.append(tr("Title"));
-    ui.listView->sortItems(m_key_index, Qt::AscendingOrder);
+    ui.listView->sortItems(_key_index, Qt::AscendingOrder);
     ui.listView->setHeaderLabels(header);
-    ui.listView->hideColumn(m_id_index);
+    ui.listView->hideColumn(_id_index);
     ui.listView->setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    settings->setDefaultValue("c2bReferenceList/LyXPipe", QDir::cleanPath(QDir::homePath() + QDir::separator() + ".lyx/lyxpipe.in"));
-    lyxpipe = settings->value("c2bReferenceList/LyXPipe").toString();
     citeEntryAction = new QAction(this);
-    citeEntryAction->setShortcut(tr("Alt+X"));
-    citeEntryAction->setText(tr("Cite Selected Entries -- LyX pipe"));
+    citeEntryAction->setShortcut(tr("Alt+C"));
+    citeEntryAction->setText(tr("Cite Selected Entries"));
     connect(citeEntryAction, SIGNAL(triggered()), this, SLOT(citeEntry()));
     ui.listView->addAction(citeEntryAction);
-    citeEntry2CbAction = new QAction(this);
-    citeEntry2CbAction->setShortcut(tr("Alt+C"));
-    citeEntry2CbAction->setText(tr("Cite Selected Entries to Clipboard"));
-    connect(citeEntry2CbAction, SIGNAL(triggered()), this, SLOT(citeEntry2Cb()));
-    ui.listView->addAction(citeEntry2CbAction);
 
     c2bUtils::addSeparator(ui.listView);
     openFileAction = new QAction(this);
@@ -118,6 +113,7 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
 
     c2bUtils::addSeparator(ui.listView);
     clearSelectionsAction = new QAction(this);
+    clearSelectionsAction->setShortcut(Qt::Key_Delete);
     clearSelectionsAction->setText(tr("Clear Entry Selection"));
     clearSelectionsAction->setStatusTip(tr("Clear Entry Selection"));
     connect(clearSelectionsAction, SIGNAL(triggered()), this, SLOT(clearSelections()));
@@ -125,6 +121,7 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
 
     c2bUtils::addSeparator(ui.listView);
     refreshListAction = new QAction(this);
+    refreshListAction->setShortcut(QKeySequence(QKeySequence::Refresh));
     refreshListAction->setText(tr("Refresh List and Browser View"));
     refreshListAction->setStatusTip(tr("Refresh List and Browser View"));
     connect(refreshListAction, SIGNAL(triggered()), this, SLOT(refreshList()));
@@ -136,50 +133,50 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     connect(ui.listView, SIGNAL(itemSelectionChanged()), this, SLOT(itemSelectionChanged()));
 
     // Browser functionality
-    m_references_html = c2bUtils::fileToString(":/htm/htm/references.html");
-    m_references_html.replace("GET_CB2BIB_VERSION_NUMBER", C2B_VERSION);
-    m_bib_item_html = c2bUtils::fileToString(":/htm/htm/bib_item.html");
-    QString references_css = c2bUtils::fileToString(settings->fileName("cb2Bib/BrowserCssFile"));
+    _references_html = c2bUtils::fileToString(":/htm/htm/references.html");
+    _references_html.replace("GET_CB2BIB_VERSION_NUMBER", C2B_VERSION);
+    _bib_item_html = c2bUtils::fileToString(":/htm/htm/bib_item.html");
+    QString references_css(c2bUtils::fileToString(_settingsP->fileName("cb2Bib/BrowserCssFile")));
     if (references_css.isEmpty())
         references_css = c2bUtils::fileToString(":/htm/htm/references.css");
-    browserPtr->document()->setDefaultStyleSheet(references_css);
+    _browserP->document()->setDefaultStyleSheet(references_css);
 
     openTextLocalSearchAction = new QAction(this);
     openTextLocalSearchAction->setText(tr("Local Search for selected text"));
     openTextLocalSearchAction->setStatusTip(tr("Local Search for selected text"));
     connect(openTextLocalSearchAction, SIGNAL(triggered()), this, SLOT(openTextLocalSearch()));
     openTextLocalSearchAction->setEnabled(false);
-    connect(browserPtr, SIGNAL(copyAvailable(bool)), openTextLocalSearchAction, SLOT(setEnabled(bool)));
+    connect(_browserP, SIGNAL(copyAvailable(bool)), openTextLocalSearchAction, SLOT(setEnabled(bool)));
     openTextWebSearchAction = new QAction(this);
     openTextWebSearchAction->setText(tr("Web Search for selected text"));
     openTextWebSearchAction->setStatusTip(tr("Web Search for selected text"));
     connect(openTextWebSearchAction, SIGNAL(triggered()), this, SLOT(openTextWebSearch()));
     openTextWebSearchAction->setEnabled(false);
-    connect(browserPtr, SIGNAL(copyAvailable(bool)), openTextWebSearchAction, SLOT(setEnabled(bool)));
+    connect(_browserP, SIGNAL(copyAvailable(bool)), openTextWebSearchAction, SLOT(setEnabled(bool)));
 
     QList<QAction*> al = ui.listView->actions();
-    for (int i = 0; i < 3; ++i)
-        browserPtr->addAction(al.at(i));
-    browserPtr->addAction(openTextLocalSearchAction);
-    browserPtr->addAction(openTextWebSearchAction);
-    c2bUtils::addSeparator(browserPtr);
-    for (int i = 7; i < al.count(); ++i)
-        browserPtr->addAction(al.at(i));
-    browserPtr->setContextMenuPolicy(Qt::ActionsContextMenu);
+    for (int i = 0; i < 2; ++i)
+        _browserP->addAction(al.at(i));
+    _browserP->addAction(openTextLocalSearchAction);
+    _browserP->addAction(openTextWebSearchAction);
+    c2bUtils::addSeparator(_browserP);
+    for (int i = 6; i < al.count(); ++i)
+        _browserP->addAction(al.at(i));
+    _browserP->setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    connect(browserPtr, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(openLink(const QUrl&)));
-    connect(browserPtr, SIGNAL(highlighted(const QString&)), parent->parent(), SLOT(showMessage(const QString&)));
+    connect(_browserP, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(openLink(const QUrl&)));
+    connect(_browserP, SIGNAL(highlighted(const QString&)), parentw->parent(), SLOT(showMessage(const QString&)));
 }
 
 c2bReferenceList::~c2bReferenceList()
 {}
 
 
-void c2bReferenceList::loadList(const QString& txt, c2bBibSearcher* bibSearcher)
+void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    c2bBibParser* bp = c2b::bibParser();
-    QString references_html = m_references_html;
+    c2bBibParser* bpP = c2b::bibParser();
+    QString references_html(_references_html);
     QString references;
 
     QStringList fields;
@@ -187,6 +184,7 @@ void c2bReferenceList::loadList(const QString& txt, c2bBibSearcher* bibSearcher)
     fields.append("author");
     fields.append("booktitle");
     fields.append("doi");
+    fields.append("editor");
     fields.append("file");
     fields.append("journal");
     fields.append("pages");
@@ -195,57 +193,61 @@ void c2bReferenceList::loadList(const QString& txt, c2bBibSearcher* bibSearcher)
     fields.append("volume");
     fields.append("year");
     bibReference ref;
-    bp->initReferenceParsing(editorPtr->editFileName(), fields, &ref);
-    int ref_counter = 0;
+    bpP->initReferenceParsing(_editorP->editorFilename(), fields, &ref);
+    const QRegExp initials1("\\b\\w\\b");
+    const QRegExp initials2("[^\\w\\s]");
+    const QRegExp nonletters("[^\\w\\s-]");
+    int ref_counter(0);
 
-    while (bp->referencesIn(txt, &ref))
+    while (bpP->referencesIn(txt, &ref))
     {
         ref_counter++;
-        QString key = ref.keyName;
-        QString abstract = ref.value("abstract");
-        QString author = ref.value("author");
-        QString doi = ref.value("doi");
-        QString file = ref.value("file");
-        QString journal = ref.value("journal");
-        QString pages = ref.value("pages");
-        QString url = ref.value("url");
-        QString title = ref.value("title");
-        QString volume = ref.value("volume");
-        QString year = ref.value("year");
-        QString author_long;
-        QString ID;
-        QString link;
 
+        QString author(ref.anyAuthor());
+        QString author_long;
         if (!author.isEmpty())
         {
+            author = bpP->authorFromBibTeX(author);
             author_long = author;
-            author_long.remove(QRegExp("[^\\w\\s-]"));
+            author_long.remove(nonletters);
             author_long.replace(" and ", ", ");
-            author_long = author_long.simplified();
-            author.remove(QRegExp("\\b\\w\\b"));
-            author.remove(QRegExp("[^\\w\\s]"));
+            c2bUtils::simplifyString(author_long);
+            author_long += '.';
+            author.remove(initials1);
+            author.remove(initials2);
             author.replace(" and ", ", ");
-            author = author.simplified();
+            c2bUtils::simplifyString(author);
         }
-        if (title.isEmpty())
-            title = ref.value("booktitle");
-        c2bUtils::cleanTitle(title);
 
+        QString title(ref.anyTitle());
+        c2bUtils::cleanTitle(title, true);
+
+        QString doi(ref.value("doi"));
         if (!doi.isEmpty())
             if (!doi.startsWith("http://"))
                 doi = "http://dx.doi.org/" + QUrl::toPercentEncoding(doi);
+
+        const QString file(ref.value("file"));
+        const QString url(ref.value("url"));
+        QString link;
         if (!file.isEmpty())
-            link = file;
+            link = QDir::cleanPath(file);
         else if (!url.isEmpty())
             link = url;
         else if (!doi.isEmpty())
             link = doi;
-        ID.setNum(ref_counter);
 
-        doiList.append(doi);
-        fileList.append(file);
-        urlList.append(url);
-        positionList.append(ref.positionValue);
+        QString ID;
+        ID.setNum(ref_counter);
+        QString year(ref.value("year"));
+        const QString abstract(ref.value("abstract"));
+        const QString journal(ref.anyJournal());
+        const QString key(ref.citeidName);
+
+        _doiList.append(doi);
+        _fileList.append(file);
+        _urlList.append(url);
+        _positionList.append(ref.positionValue);
         QStringList dataList;
         dataList.append(key);
         dataList.append(ID);
@@ -253,25 +255,24 @@ void c2bReferenceList::loadList(const QString& txt, c2bBibSearcher* bibSearcher)
         dataList.append(journal);
         dataList.append(author);
         dataList.append(title);
-        QTreeWidgetItem* qi = new QTreeWidgetItem(dataList);
-        qi->setStatusTip(m_journal_index, bp->fullJournal(journal));
-        qi->setStatusTip(m_author_index, author_long);
-        qi->setStatusTip(m_title_index, title);
+        TreeWidgetItem* qi = new TreeWidgetItem(dataList);
+        qi->setStatusTip(_journal_index, bpP->fullJournal(journal));
+        qi->setStatusTip(_author_index, author_long);
+        qi->setStatusTip(_title_index, title);
         ui.listView->insertTopLevelItem(0, qi);
 
-        if (!author_long.isEmpty())
-            author_long += ".";
-        title.remove(QRegExp("\\.$"));
+        QString pages(ref.value("pages"));
+        const QString volume(ref.value("volume"));
         if (!pages.isEmpty())
         {
             if (!volume.isEmpty())
                 pages = ", " + pages;
             else
-                pages = " " + pages;
+                pages = ' ' + pages;
         }
         if (!year.isEmpty())
-            year = "(" + year + ").";
-        QString bib_item_html = m_bib_item_html;
+            year = '(' + year + ").";
+        QString bib_item_html(_bib_item_html);
         bib_item_html.replace("GET_REFERENCE_ANCHOR_ID", ID);
         bib_item_html.replace("GET_REFERENCE_ANCHOR_NAME", ID);
         bib_item_html.replace("GET_REFERENCE_AUTHOR", author_long);
@@ -281,88 +282,45 @@ void c2bReferenceList::loadList(const QString& txt, c2bBibSearcher* bibSearcher)
         bib_item_html.replace("GET_REFERENCE_TITLE", c2bUtils::toHtmlString(title));
         bib_item_html.replace("GET_REFERENCE_VOLUME", volume);
         bib_item_html.replace("GET_REFERENCE_YEAR", year);
-        if (bibSearcher)
-            bib_item_html.replace("GET_REFERENCE_ABSTRACT", bibSearcher->highlight(abstract) +
-                                  bibSearcher->hitMap.value(ref.rawReference));
+        if (searcher)
+            bib_item_html.replace("GET_REFERENCE_ABSTRACT", searcher->highlight(abstract) + searcher->hitValue(ref.rawReference));
         else
             bib_item_html.replace("GET_REFERENCE_ABSTRACT", c2bUtils::toHtmlString(abstract));
         references += bib_item_html;
     }
 
     ui.listView->sortItems(ui.listView->sortColumn(), ui.listView->header()->sortIndicatorOrder());
-    ui.listView->resizeColumnToContents(m_year_index);
+    ui.listView->resizeColumnToContents(_year_index);
     references_html.replace("GET_REFERENCES", references);
-    browserPtr->updateHtml(references_html);
+    _browserP->updateHtml(references_html);
     QApplication::restoreOverrideCursor();
     c2b::showMessage(tr("Parsed %1 references.").arg(ref_counter));
 }
 
 void c2bReferenceList::citeEntry()
 {
-    // This procedure was adapted from Tellico
-    // Tellico (C) 2003-2005 by Robby Stephenson
-    QByteArray pipe = QFile::encodeName(lyxpipe);
-    QString errorStr = tr("Unable to write to the server pipe at '%1'.").arg(QString(pipe));
-
-    if (!QFile::exists(pipe))
-    {
-        QMessageBox::warning(this, tr("Warning - cb2Bib"), errorStr, QMessageBox::Ok);
-        return;
-    }
-
-    int pipeFd = ::open(pipe, O_WRONLY);
-    QFile file(QString::fromUtf8(pipe));
-    if (file.open(pipeFd, QIODevice::WriteOnly))
-    {
-        QString refs;
-        QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
-        while (*it)
-        {
-            if (!(*it)->text(m_key_index).isEmpty())
-                refs += (*it)->text(m_key_index) + " ";
-            ++it;
-        }
-        refs = refs.trimmed();
-        // pybliographer uses comma-space, and pyblink expects the space there
-        refs.replace(" ", ", ");
-        QTextStream st(&file);
-        st << QString::fromLatin1("LYXCMD:cb2bib:citation-insert:%1\n").arg(refs).toLatin1();
-        file.flush();
-        file.close();
-    }
-    else
-        QMessageBox::warning(this, tr("Warning - cb2Bib"), errorStr, QMessageBox::Ok);
-    ::close(pipeFd);
-}
-
-void c2bReferenceList::citeEntry2Cb()
-{
-    QString refs;
+    QStringList keys;
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        if (!(*it)->text(m_key_index).isEmpty())
-            refs += (*it)->text(m_key_index) + " ";
+        if (!(*it)->text(_key_index).isEmpty())
+            keys.append((*it)->text(_key_index));
         ++it;
     }
-    refs = refs.trimmed();
-    refs.replace(" ", ", ");
-    refs = "\\cite{" + refs + "}";
-    QClipboard *cb = QApplication::clipboard();
-    cb->setText(refs, QClipboard::Clipboard);
+    _citerP->cite(keys);
 }
 
 void c2bReferenceList::openDOI()
 {
-    bool zdoi = false;
+    bool zdoi(false);
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        QString doi = doiList.at((*it)->text(m_id_index).toInt() - 1);
+        const QString doi(_doiList.at((*it)->text(_id_index).toInt() - 1));
         if (!doi.isEmpty())
         {
             zdoi = true;
-            c2b::openFile(doi);
+            c2bUtils::openFile(doi, parentWidget());
         }
         ++it;
     }
@@ -372,15 +330,15 @@ void c2bReferenceList::openDOI()
 
 void c2bReferenceList::openFile()
 {
-    bool zfile = false;
+    bool zfile(false);
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        QString file = fileList.at((*it)->text(m_id_index).toInt() - 1);
+        const QString file(_fileList.at((*it)->text(_id_index).toInt() - 1));
         if (!file.isEmpty())
         {
             zfile = true;
-            c2b::openFile(file);
+            c2bUtils::openFile(file, parentWidget());
         }
         ++it;
     }
@@ -390,15 +348,15 @@ void c2bReferenceList::openFile()
 
 void c2bReferenceList::openUrl()
 {
-    bool zurl = false;
+    bool zurl(false);
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        QString url = urlList.at((*it)->text(m_id_index).toInt() - 1);
+        const QString url(_urlList.at((*it)->text(_id_index).toInt() - 1));
         if (!url.isEmpty())
         {
             zurl = true;
-            c2b::openFile(url);
+            c2bUtils::openFile(url, parentWidget());
         }
         ++it;
     }
@@ -408,32 +366,31 @@ void c2bReferenceList::openUrl()
 
 void c2bReferenceList::openLink(const QUrl& ln)
 {
-    QString ln_str = ln.toString();
+    QString ln_str(ln.toString());
     if (ln_str.isEmpty())
-        c2b::showMessage(tr("No available link for this reference."));
+        c2b::showMessage(tr("No link available for this reference."));
     else if (ln_str.startsWith("Select reference "))
         scrollToReference(ln_str.remove(QRegExp("\\D")));
     else if (ln_str.startsWith("Edit reference"))
         emit openFile(ln_str.replace(QRegExp("^.+\\[(.+)\\]$"), "\\1"));
     else
-        c2b::openFile(ln_str);
+        c2bUtils::openFile(ln_str, parentWidget());
 }
 
 void c2bReferenceList::openAuthorWebSearch()
 {
-    QString searchEngine = settings->value("c2bReferenceList/SearchEngine").toString();
-    bool zwebs = false;
+    const QString searchEngine(_settingsP->value("c2bReferenceList/SearchEngine").toString());
+    bool zwebs(false);
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        if (!(*it)->text(m_author_index).isEmpty())
+        if (!(*it)->text(_author_index).isEmpty())
         {
             zwebs = true;
-            QString webs = (*it)->text(m_author_index);
-            webs.remove(",");
-            webs = webs.simplified();
-            webs = searchEngine + QUrl::toPercentEncoding(webs);
-            c2b::openFile(webs);
+            QString webs((*it)->text(_author_index));
+            webs.remove(',');
+            webs = searchEngine + webs.simplified();
+            c2bUtils::openFile(webs, parentWidget());
         }
         ++it;
     }
@@ -443,20 +400,20 @@ void c2bReferenceList::openAuthorWebSearch()
 
 void c2bReferenceList::openTitleWebSearch()
 {
-    QString searchEngine = settings->value("c2bReferenceList/SearchEngine").toString();
-    bool addQuotes = settings->value("c2bReferenceList/SearchEngineAddQuotes").toBool();
-    bool zwebs = false;
+    const QString searchEngine(_settingsP->value("c2bReferenceList/SearchEngine").toString());
+    const bool addQuotes(_settingsP->value("c2bReferenceList/SearchEngineAddQuotes").toBool());
+    bool zwebs(false);
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        if (!(*it)->text(m_title_index).isEmpty())
+        if (!(*it)->text(_title_index).isEmpty())
         {
             zwebs = true;
-            QString webs = (*it)->text(m_title_index);
+            QString webs((*it)->text(_title_index));
             if (addQuotes)
-                webs = "\"" + webs + "\"";
-            webs = searchEngine + QUrl::toPercentEncoding(webs);
-            c2b::openFile(webs);
+                webs = '\"' + webs + '\"';
+            webs = searchEngine + webs;
+            c2bUtils::openFile(webs, parentWidget());
         }
         ++it;
     }
@@ -466,12 +423,12 @@ void c2bReferenceList::openTitleWebSearch()
 
 void c2bReferenceList::openTextWebSearch()
 {
-    QString searchEngine = settings->value("c2bReferenceList/SearchEngine").toString();
-    QString webs = browserPtr->textCursor().selectedText();
-    if (settings->value("c2bReferenceList/SearchEngineAddQuotes").toBool())
-        webs = "\"" + webs + "\"";
-    webs = searchEngine + QUrl::toPercentEncoding(webs);
-    c2b::openFile(webs);
+    const QString searchEngine(_settingsP->value("c2bReferenceList/SearchEngine").toString());
+    QString webs(_browserP->textCursor().selectedText());
+    if (_settingsP->value("c2bReferenceList/SearchEngineAddQuotes").toBool())
+        webs = '\"' + webs + '\"';
+    webs = searchEngine + webs;
+    c2bUtils::openFile(webs, parentWidget());
 }
 
 void c2bReferenceList::webSearchSettings()
@@ -482,33 +439,33 @@ void c2bReferenceList::webSearchSettings()
 
 void c2bReferenceList::openTextLocalSearch()
 {
-    QString text = browserPtr->textCursor().selectedText();
-    QString fn = editorPtr->editFileName();
+    const QString text(_browserP->textCursor().selectedText());
+    const QString fn(_editorP->editorFilename());
     c2b::doSearchInFiles(text, fn);
 }
 
 void c2bReferenceList::refreshList()
 {
-    doiList.clear();
-    fileList.clear();
-    urlList.clear();
-    positionList.clear();
+    _doiList.clear();
+    _fileList.clear();
+    _urlList.clear();
+    _positionList.clear();
     ui.listView->clear();
     ui.comboFilter->clearEditText();
-    loadList(editorPtr->toPlainText());
+    loadList(_editorP->toPlainText());
 }
 
 void c2bReferenceList::goToReference(const QString& id)
 {
-    QTextCursor tc = editorPtr->textCursor();
-    tc.setPosition(positionList.at(id.toInt() - 1));
-    editorPtr->setTextCursor(tc);
-    editorPtr->verticalScrollBar()->setValue(editorPtr->verticalScrollBar()->maximum());
-    editorPtr->ensureCursorVisible();
+    QTextCursor tc(_editorP->textCursor());
+    tc.setPosition(_positionList.at(id.toInt() - 1));
+    _editorP->setTextCursor(tc);
+    _editorP->verticalScrollBar()->setValue(_editorP->verticalScrollBar()->maximum());
+    _editorP->ensureCursorVisible();
 
-    browserPtr->scrollToAnchor(id);
-    int scrollPosition = browserPtr->verticalScrollBar()->value();
-    browserPtr->verticalScrollBar()->setValue(scrollPosition - 10);
+    _browserP->scrollToAnchor(id);
+    int scrollPosition(_browserP->verticalScrollBar()->value());
+    _browserP->verticalScrollBar()->setValue(scrollPosition - 10);
 }
 
 void c2bReferenceList::goToReference(const int position)
@@ -517,17 +474,17 @@ void c2bReferenceList::goToReference(const int position)
     // citation is edited in the original file. If this file is changed multiple times,
     // positions in the search browser get outdated, so the mapping position-id is inexact.
     // Thus, search for the closet reference.
-    int ip = 0;
-    int pdiff_min = 1000000;
-    for (int i = 0; i < positionList.count(); ++i)
+    int ip(0);
+    int pdiff_min(1000000);
+    for (int i = 0; i < _positionList.count(); ++i)
     {
-        int p = positionList.at(i);
+        int p(_positionList.at(i));
         if (p == position)
         {
             ip = i;
             break;
         }
-        int pdiff = abs(p - position);
+        int pdiff(abs(p - position));
         if (pdiff < pdiff_min)
         {
             pdiff_min = pdiff;
@@ -542,7 +499,7 @@ void c2bReferenceList::goToReference(QTreeWidgetItem* ref)
 {
     if (ref == 0)
         return;
-    QString id = ref->text(m_id_index);
+    const QString id(ref->text(_id_index));
     goToReference(id);
 }
 
@@ -556,11 +513,11 @@ void c2bReferenceList::scrollToReference(const QString& id)
     item->setSelected(!item->isSelected());
     ui.listView->scrollToItem(item);
 
-    QTextCursor tc = editorPtr->textCursor();
-    tc.setPosition(positionList.at(id.toInt() - 1));
-    editorPtr->setTextCursor(tc);
-    editorPtr->verticalScrollBar()->setValue(editorPtr->verticalScrollBar()->maximum());
-    editorPtr->ensureCursorVisible();
+    QTextCursor tc(_editorP->textCursor());
+    tc.setPosition(_positionList.at(id.toInt() - 1));
+    _editorP->setTextCursor(tc);
+    _editorP->verticalScrollBar()->setValue(_editorP->verticalScrollBar()->maximum());
+    _editorP->ensureCursorVisible();
 }
 
 void c2bReferenceList::clearSelections()
@@ -578,32 +535,30 @@ void c2bReferenceList::clearSelections()
 
 void c2bReferenceList::itemSelectionChanged()
 {
-    int entries = 0;
-    int doi = 0;
-    int file = 0;
-    int url = 0;
-    int author = 0;
-    int title = 0;
+    int entries(0);
+    int doi(0);
+    int file(0);
+    int url(0);
+    int author(0);
+    int title(0);
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        if (!doiList.at((*it)->text(m_id_index).toInt() - 1).isEmpty())
+        if (!_doiList.at((*it)->text(_id_index).toInt() - 1).isEmpty())
             ++doi;
-        if (!fileList.at((*it)->text(m_id_index).toInt() - 1).isEmpty())
+        if (!_fileList.at((*it)->text(_id_index).toInt() - 1).isEmpty())
             ++file;
-        if (!urlList.at((*it)->text(m_id_index).toInt() - 1).isEmpty())
+        if (!_urlList.at((*it)->text(_id_index).toInt() - 1).isEmpty())
             ++url;
-        if (!(*it)->text(m_author_index).isEmpty())
+        if (!(*it)->text(_author_index).isEmpty())
             ++author;
-        if (!(*it)->text(m_title_index).isEmpty())
+        if (!(*it)->text(_title_index).isEmpty())
             ++title;
         ++entries;
         ++it;
     }
     citeEntryAction->setEnabled(entries > 0);
-    citeEntryAction->setStatusTip(tr("Cite Selected Entries -- LyX pipe. %1 Entries selected.").arg(entries));
-    citeEntry2CbAction->setEnabled(entries > 0);
-    citeEntry2CbAction->setStatusTip(tr("Cite Selected Entries to Clipboard. %1 Entries selected.").arg(entries));
+    citeEntryAction->setStatusTip(tr("Cite Selected Entries. %1 Entries selected.").arg(entries));
     openDOIAction->setEnabled(doi > 0);
     openDOIAction->setStatusTip(tr("Browse Reference by DOI. %1 DOIs in selected entries.").arg(doi));
     openFileAction->setEnabled(file > 0);
@@ -623,21 +578,16 @@ QStringList c2bReferenceList::selectedKeys() const
     QTreeWidgetItemIterator it(ui.listView, QTreeWidgetItemIterator::Selected | QTreeWidgetItemIterator::NotHidden);
     while (*it)
     {
-        if (!(*it)->text(m_key_index).isEmpty())
-            keys.append((*it)->text(m_key_index));
+        if (!(*it)->text(_key_index).isEmpty())
+            keys.append((*it)->text(_key_index));
         ++it;
     }
     return keys;
 }
 
-void c2bReferenceList::setLyxPipe()
+void c2bReferenceList::setLyXPipe()
 {
-    QString new_pn = c2bFileDialog::getSystemFileName(this, "Select LyX pipe", lyxpipe, "All (*)");
-    if (!new_pn.isEmpty())
-    {
-        lyxpipe = new_pn;
-        settings->setValue("c2bReferenceList/LyXPipe", lyxpipe);
-    }
+    _citerP->setLyXPipe();
 }
 
 
@@ -647,27 +597,17 @@ void c2bReferenceList::setLyxPipe()
 
 void c2bReferenceList::setupFilterBar()
 {
-    m_filter_mode = settings->value("c2bReferenceList/FilterMode", "Approximate string").toString();
+    const QStringList types(searchPattern::types());
+    _filter_mode = _settingsP->value("c2bReferenceList/FilterMode", types.first()).toString();
     QActionGroup* filterMode = new QActionGroup(this);
     filterMode->setExclusive(true);
-    QAction* act = filterMode->addAction("Approximate string");
-    act->setCheckable(true);
-    if (m_filter_mode == "Approximate string") act->setChecked(true);
-    act = filterMode->addAction("Fixed string");
-    act->setCheckable(true);
-    if (m_filter_mode == "Fixed string") act->setChecked(true);
-    act = filterMode->addAction("Fixed string: All Words");
-    act->setCheckable(true);
-    if (m_filter_mode == "Fixed string: All Words") act->setChecked(true);
-    act = filterMode->addAction("Fixed string: Any Word");
-    act->setCheckable(true);
-    if (m_filter_mode == "Fixed string: Any Word") act->setChecked(true);
-    act = filterMode->addAction("Regular expression");
-    act->setCheckable(true);
-    if (m_filter_mode == "Regular expression") act->setChecked(true);
-    act = filterMode->addAction("Wildcard");
-    act->setCheckable(true);
-    if (m_filter_mode == "Wildcard") act->setChecked(true);
+    for (int i = 0; i < types.count(); ++i)
+    {
+        const QString& t = types.at(i);
+        QAction* act = filterMode->addAction(t);
+        act->setCheckable(true);
+        if (_filter_mode == t) act->setChecked(true);
+    }
     QMenu* filterModeM = new QMenu(this);
     filterModeM->addActions(filterMode->actions());
     ui.filterB->setMenu(filterModeM);
@@ -677,8 +617,8 @@ void c2bReferenceList::setupFilterBar()
 
 void c2bReferenceList::setFilterMode(QAction* mode)
 {
-    m_filter_mode = mode->text();
-    settings->setValue("c2bReferenceList/FilterMode", m_filter_mode);
+    _filter_mode = mode->text();
+    _settingsP->setValue("c2bReferenceList/FilterMode", _filter_mode);
     filterList();
 }
 
@@ -690,7 +630,7 @@ void c2bReferenceList::blockFilterSignals()
 
 void c2bReferenceList::filterList()
 {
-    QString text = ui.comboFilter->currentText();
+    const QString text(ui.comboFilter->currentText());
     if (text.isEmpty())
     {
         QTreeWidgetItemIterator it(ui.listView);
@@ -702,12 +642,12 @@ void c2bReferenceList::filterList()
     }
     else
     {
-        c2bSearchPattern pattern(text, m_filter_mode);
+        searchPattern pattern(text, _filter_mode);
         QTreeWidgetItemIterator it(ui.listView);
         while (*it)
         {
-            QTreeWidgetItem *item = *it;
-            if (pattern.matches(item->text(m_author_index)) || pattern.matches(item->text(m_title_index)))
+            QTreeWidgetItem* item = *it;
+            if (pattern.matches(item->text(_author_index)) || pattern.matches(item->text(_title_index)))
                 item->setHidden(false);
             else
                 item->setHidden(true);
@@ -721,8 +661,8 @@ void c2bReferenceList::filterList()
 
 void c2bReferenceList::keepFilterPattern()
 {
-    QString txt = ui.comboFilter->currentText();
-    if (!txt.isEmpty())
-        if (ui.comboFilter->findText(txt) < 0)
-            ui.comboFilter->addItem(txt);
+    const QString text(ui.comboFilter->currentText());
+    if (!text.isEmpty())
+        if (ui.comboFilter->findText(text) < 0)
+            ui.comboFilter->addItem(text);
 }
