@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BREFERENCELIST_H
@@ -11,7 +11,9 @@
 
 #include <QWidget>
 
-class c2bBibSearcher;
+
+class bibSearcher;
+class c2bCoreCiter;
 class c2bRLWebSearchSettings;
 class c2bSettings;
 class c2bTextBrowser;
@@ -23,10 +25,9 @@ class c2bReferenceList : public QWidget
     Q_OBJECT
 
 public:
-    c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget* parent = 0);
+    c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget* parentw = 0);
     ~c2bReferenceList();
 
-    QAction* citeEntry2CbAction;
     QAction* citeEntryAction;
     QAction* clearSelectionsAction;
     QAction* openAuthorsWebSearchAction;
@@ -44,9 +45,9 @@ public:
 
 
 public slots:
-    void loadList(const QString& txt, c2bBibSearcher* bibSearcher = 0);
+    void loadList(const QString& txt, bibSearcher* searcher = 0);
     void refreshList();
-    void setLyxPipe();
+    void setLyXPipe();
 
 
 signals:
@@ -56,7 +57,6 @@ signals:
 
 protected slots:
     void citeEntry();
-    void citeEntry2Cb();
     void clearSelections();
     void goToReference(QTreeWidgetItem* ref);
     void itemSelectionChanged();
@@ -73,24 +73,24 @@ protected slots:
 
 
 private:
-    QList<int> positionList;
-    QString lyxpipe;
-    QString m_bib_item_html;
-    QString m_filter_mode;
-    QString m_references_html;
-    QStringList doiList;
-    QStringList fileList;
-    QStringList urlList;
+    QList<int> _positionList;
+    QString _bib_item_html;
+    QString _filter_mode;
+    QString _references_html;
+    QStringList _doiList;
+    QStringList _fileList;
+    QStringList _urlList;
     Ui::c2bReferenceList ui;
-    c2bSettings* settings;
-    c2bTextBrowser* browserPtr;
-    c2bTextEdit* editorPtr;
-    int m_author_index;
-    int m_id_index;
-    int m_journal_index;
-    int m_key_index;
-    int m_title_index;
-    int m_year_index;
+    c2bCoreCiter* _citerP;
+    c2bSettings* _settingsP;
+    c2bTextBrowser* _browserP;
+    c2bTextEdit* _editorP;
+    int _author_index;
+    int _id_index;
+    int _journal_index;
+    int _key_index;
+    int _title_index;
+    int _year_index;
     void setupFilterBar();
 
 
