@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BSAVEREGEXP_H
@@ -12,7 +12,7 @@
 #include <QDialog>
 
 
-class c2bREHighlighter;
+class c2bSaveREHighlighter;
 
 class c2bSaveRegExp : public QDialog
 {
@@ -20,7 +20,7 @@ class c2bSaveRegExp : public QDialog
     Q_OBJECT
 
 public:
-    c2bSaveRegExp(QString& rx, QWidget* parent = 0);
+    c2bSaveRegExp(const QStringList& pattern, const QString& input, QWidget* parentw = 0);
     ~c2bSaveRegExp();
 
 
@@ -31,11 +31,19 @@ signals:
 public slots:
     void accept();
     void help();
+    void updateInput(const QString& text);
 
 
 private:
+    QRegExp _pattern_rx;
+    QString _input_text;
     Ui::c2bSaveRegExp ui;
-    c2bREHighlighter* reS;
+    c2bSaveREHighlighter* _sreS;
+
+
+private slots:
+    void inputMightHaveChanged();
+    void setInformation();
 
 };
 
