@@ -1,18 +1,21 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSearchInFiles.h"
+
 #include "c2b.h"
-#include "c2bBibSearcher.h"
+#include "c2bUtils.h"
+
+#include <bibSearcher.h>
 
 #include <QFileInfo>
 #include <QTime>
 
 
-c2bSearchInFiles::c2bSearchInFiles(const QString& file, QWidget* parent) : QDialog(parent)
+c2bSearchInFiles::c2bSearchInFiles(const QString& file, QWidget* parentw) : QDialog(parentw)
 {
     ui.setupUi(this);
     // Set blank title to columns 0 and 4. Qt 4.4.0 needs it, otherwise it takes column number as default title.
@@ -22,18 +25,22 @@ c2bSearchInFiles::c2bSearchInFiles(const QString& file, QWidget* parent) : QDial
 
     for (int i = 0; i < ITEMS_IN_SEARCH_PATTERN; ++i)
         ui.patternList->resizeColumnToContents(i);
+    ui.buttonBox->button(QDialogButtonBox::Abort)->setAutoDefault(false);
+    ui.buttonBox->button(QDialogButtonBox::Abort)->setDefault(false);
     ui.buttonBox->button(QDialogButtonBox::Abort)->setEnabled(false);
-    searchB = new QPushButton(tr("Search"));
-    ui.buttonBox->addButton(searchB, QDialogButtonBox::ActionRole);
-    searchB->setAutoDefault(true);
-    searchB->setDefault(true);
-    searchB->setEnabled(false);
+    ui.buttonBox->button(QDialogButtonBox::Close)->setAutoDefault(false);
+    ui.buttonBox->button(QDialogButtonBox::Close)->setDefault(false);
+    _searchB = new QPushButton(tr("Search"));
+    ui.buttonBox->addButton(_searchB, QDialogButtonBox::ActionRole);
+    _searchB->setAutoDefault(true);
+    _searchB->setDefault(true);
+    _searchB->setEnabled(false);
 
-    m_bibtex_file.clear();
-    m_bibtex_dir.clear();
+    _bibtex_file.clear();
+    _bibtex_dir.clear();
     setBibTeXFile(file);
 
-    connect(searchB, SIGNAL(clicked()), this, SLOT(searchB_clicked()));
+    connect(_searchB, SIGNAL(clicked()), this, SLOT(searchB_clicked()));
     connect(ui.allBibFiles, SIGNAL(clicked()), this, SLOT(setBibTeXFile()));
     connect(ui.buttonBox, SIGNAL(helpRequested()), this, SLOT(help()));
     connect(ui.pattern, SIGNAL(patternAvailable(bool)), this, SLOT(updateForm()));
@@ -50,7 +57,7 @@ void c2bSearchInFiles::updateForm()
     ui.addPatternB->setEnabled(ui.pattern->isAvailable());
     ui.Boolean->setEnabled((ui.patternList->topLevelItemCount() > 1) ||
                            (ui.pattern->isAvailable() && ui.patternList->topLevelItemCount() > 0));
-    searchB->setEnabled(ui.pattern->isAvailable() || ui.patternList->topLevelItemCount() > 0);
+    _searchB->setEnabled(!_bibtex_dir.isEmpty() && (ui.pattern->isAvailable() || ui.patternList->topLevelItemCount() > 0));
     if (ui.patternList->currentItem())
     {
         ui.deletePatternB->setEnabled(true);
@@ -61,12 +68,12 @@ void c2bSearchInFiles::updateForm()
         ui.deletePatternB->setEnabled(false);
         ui.editPatternB->setEnabled(false);
     }
-    ui.searchLog->setText(searchLogText);
+    ui.searchLog->setText(_search_log);
 }
 
 void c2bSearchInFiles::on_addPatternB_clicked()
 {
-    new QTreeWidgetItem(ui.patternList, ui.pattern->pattern());
+    new QTreeWidgetItem(ui.patternList, ui.pattern->patterns());
     for (int i = 0; i < ITEMS_IN_SEARCH_PATTERN; ++i)
         ui.patternList->resizeColumnToContents(i);
     ui.pattern->clear();
@@ -76,8 +83,7 @@ void c2bSearchInFiles::on_addPatternB_clicked()
 void c2bSearchInFiles::on_deletePatternB_clicked()
 {
     QTreeWidgetItem* item = ui.patternList->currentItem();
-    if (item)
-        delete item;
+    delete item;
     item = ui.patternList->currentItem();
     if (item)
         ui.patternList->currentItem()->setSelected(true);
@@ -94,7 +100,7 @@ void c2bSearchInFiles::on_editPatternB_clicked()
             ui_editor.buttonBox->button(QDialogButtonBox::Ok), SLOT(setEnabled(bool)));
     if (editor.exec() == QDialog::Accepted)
     {
-        QStringList pattern = ui_editor.pattern->pattern();
+        const QStringList pattern(ui_editor.pattern->patterns());
         for (int i = 0; i < ITEMS_IN_SEARCH_PATTERN; ++i)
             item->setText(i, pattern.at(i));
         for (int i = 0; i < ITEMS_IN_SEARCH_PATTERN; ++i)
@@ -105,19 +111,19 @@ void c2bSearchInFiles::on_editPatternB_clicked()
 void c2bSearchInFiles::searchB_clicked()
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    searchB->setEnabled(false);
+    _searchB->setEnabled(false);
     ui.buttonBox->button(QDialogButtonBox::Abort)->setEnabled(true);
 
-    ui.searchLog->setText(searchLogText);
-    c2bBibSearcher searcher;
+    ui.searchLog->setText(_search_log);
+    bibSearcher searcher(c2b::bibParser());
     connect(ui.buttonBox->button(QDialogButtonBox::Abort), SIGNAL(clicked()), &searcher, SLOT(abort()));
-    searcher.setScope(m_bibtex_file, m_bibtex_dir, ui.allBibFiles->isChecked(), ui.documentFiles->isChecked());
+    searcher.setSearchScope(_bibtex_file, _bibtex_dir, ui.allBibFiles->isChecked(), ui.documentFiles->isChecked());
     searcher.setSimplifySource(ui.simplifySource->isChecked());
     searcher.setBoolean(ui.Boolean->currentText() == "All");
     if (ui.addPatternB->isEnabled())
     {
-        QStringList p = ui.pattern->pattern();
-        searcher.addPattern(p.at(0) == "NOT", p.at(1) == "Sensitive", p.at(2), p.at(3), p.at(4), p.at(5));
+        const QStringList p(ui.pattern->patterns());
+        searcher.addPattern(p.at(0) == "NOT", p.at(1) == "Sensitive", p.at(2), p.at(3), p.at(4).at(0), p.at(5));
     }
     QTreeWidgetItemIterator it(ui.patternList);
     while (*it)
@@ -125,33 +131,38 @@ void c2bSearchInFiles::searchB_clicked()
         QStringList p;
         for (int i = 0; i < ITEMS_IN_SEARCH_PATTERN; ++i)
             p.append((*it)->text(i));
-        searcher.addPattern(p.at(0) == "NOT", p.at(1) == "Sensitive", p.at(2), p.at(3), p.at(4), p.at(5));
+        searcher.addPattern(p.at(0) == "NOT", p.at(1) == "Sensitive", p.at(2), p.at(3), p.at(4).at(0), p.at(5));
         ++it;
     }
-    if (searcher.patternCount() == 0)
+    if (searcher.patternsCount() == 0)
         return;
 
     QTime t;
     t.start();
     searcher.exec();
 
-    if (searcher.hitCount() > 0 || searcher.errorCount() > 0)
+    QString search_status;
+    if (searcher.hitsCount() > 0 || searcher.errorsCount() > 0)
     {
-        if (searcher.hitCount() > 0)
-            ui.searchLog->setText(tr("Found %1 hits from %2 references (%3s)")
-                                  .arg(searcher.hitCount()).arg(searcher.referenceCount()).arg(t.elapsed() / 1000.0));
+        if (searcher.hitsCount() > 0)
+            search_status = tr("Found %1 hits from %2 references (%3s)")
+                            .arg(searcher.hitsCount()).arg(searcher.referencesCount()).arg(t.elapsed() / 1000.0);
         else
-            ui.searchLog->setText(searchLogText);
+            ui.searchLog->setText(_search_log);
         QApplication::processEvents();
-        emit searchDone(m_bibtex_dir, &searcher);
+        emit searchDone(_bibtex_dir, &searcher);
     }
-    else if (searcher.errorCount() < 0)
-        ui.searchLog->setText(tr("Search aborted"));
+    else if (searcher.errorsCount() < 0)
+        search_status = tr("Search aborted");
     else
-        ui.searchLog->setText(tr("No reference found (%1s)").arg(t.elapsed() / 1000.0));
-
+        search_status = tr("No reference found (%1s)").arg(t.elapsed() / 1000.0);
+    if (!search_status.isEmpty())
+    {
+        ui.searchLog->setText(search_status);
+        c2b::showMessage(search_status);
+    }
     ui.buttonBox->button(QDialogButtonBox::Abort)->setEnabled(false);
-    searchB->setEnabled(true);
+    _searchB->setEnabled(true);
     QApplication::restoreOverrideCursor();
 }
 
@@ -160,14 +171,22 @@ void c2bSearchInFiles::setBibTeXFile(const QString& file)
     if (!file.isEmpty())
     {
         QFileInfo fi(file);
-        m_bibtex_file = fi.absoluteFilePath();
-        m_bibtex_dir = fi.absolutePath();
+        QDir d(fi.absolutePath());
+        if (d.exists())
+        {
+            _bibtex_file = fi.absoluteFilePath();
+            _bibtex_dir = fi.absolutePath();
+        }
+        else
+            _bibtex_dir.clear();
     }
-    if (ui.allBibFiles->isChecked())
-        searchLogText = tr("Search in files at %1").arg(m_bibtex_dir);
+    if (_bibtex_dir.isEmpty())
+        _search_log = tr("No existing file or directory set for searching");
+    else if (ui.allBibFiles->isChecked())
+        _search_log = tr("Search in files at %1").arg(_bibtex_dir);
     else
-        searchLogText = tr("Search in file %1").arg(m_bibtex_file);
-    ui.searchLog->setText(searchLogText);
+        _search_log = tr("Search in file %1").arg(_bibtex_file);
+    updateForm();
 }
 
 void c2bSearchInFiles::setCurrentText(const QString& text)
@@ -180,15 +199,12 @@ void c2bSearchInFiles::setCurrentText(const QString& text)
 
 void c2bSearchInFiles::show()
 {
-    if (isMinimized())
-        showNormal();
-    raise();
-    activateWindow();
+    c2bUtils::setWidgetOnTop(this);
     ui.pattern->setFocus();
     QDialog::show();
 }
 
 void c2bSearchInFiles::help()
 {
-    c2b::displayHelp("http://www.molspaces.com/d_cb2bib-c2bsearch.php");
+    c2bUtils::displayHelp("http://www.molspaces.com/d_cb2bib-c2bsearch.php");
 }
