@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BSEARCHINFILES_H
@@ -13,7 +13,7 @@
 #include <QDialog>
 
 
-class c2bBibSearcher;
+class bibSearcher;
 
 class c2bSearchInFiles : public QDialog
 {
@@ -21,7 +21,7 @@ class c2bSearchInFiles : public QDialog
     Q_OBJECT
 
 public:
-    c2bSearchInFiles(const QString& file, QWidget* parent = 0);
+    c2bSearchInFiles(const QString& file, QWidget* parentw = 0);
     ~c2bSearchInFiles();
 
     void setCurrentText(const QString& text);
@@ -33,7 +33,7 @@ public slots:
 
 
 signals:
-    void searchDone(const QString& filename, c2bBibSearcher* searcher);
+    void searchDone(const QString& filename, bibSearcher* searcher);
 
 
 private slots:
@@ -46,12 +46,12 @@ private slots:
 
 
 private:
-    QPushButton* searchB;
-    QString m_bibtex_dir;
-    QString m_bibtex_file;
-    QString searchLogText;
-    Ui::c2bSearchInFilesPatternEdit ui_editor;
+    QPushButton* _searchB;
+    QString _bibtex_dir;
+    QString _bibtex_file;
+    QString _search_log;
     Ui::c2bSearchInFiles ui;
+    Ui::c2bSearchInFilesPatternEdit ui_editor;
 
 };
 
