@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BSEARCHINFILESPATTERN_H
@@ -12,7 +12,7 @@
 #include <QWidget>
 
 
-const int ITEMS_IN_SEARCH_PATTERN = 6;
+const int ITEMS_IN_SEARCH_PATTERN(6);
 
 class QTreeWidgetItem;
 
@@ -22,12 +22,12 @@ class c2bSearchInFilesPattern : public QWidget
     Q_OBJECT
 
 public:
-    c2bSearchInFilesPattern(QWidget* parent = 0);
+    c2bSearchInFilesPattern(QWidget* parentw = 0);
     ~c2bSearchInFilesPattern();
 
-    const QStringList pattern();
+    const QStringList patterns();
     void clear();
-    void setPattern(QTreeWidgetItem* newPattern);
+    void setPattern(QTreeWidgetItem* pattern);
     void setText(const QString& text);
 
     inline bool isAvailable() const
