@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextBrowser.h"
@@ -12,10 +12,10 @@
 #include <QScrollBar>
 
 
-c2bTextBrowser::c2bTextBrowser(QWidget* parent) : QTextBrowser(parent)
+c2bTextBrowser::c2bTextBrowser(QWidget* parentw) : QTextBrowser(parentw)
 {
-    setFrameShape(QTextEdit::StyledPanel);
-    setFrameShadow(QTextEdit::Raised);
+    setFrameShape(QTextBrowser::StyledPanel);
+    setFrameShadow(QTextBrowser::Raised);
 }
 
 c2bTextBrowser::~c2bTextBrowser()
@@ -25,23 +25,23 @@ c2bTextBrowser::~c2bTextBrowser()
 void c2bTextBrowser::setSource(const QUrl& /* dummy_name */)
 {}
 
-void c2bTextBrowser::contextMenuEvent(QContextMenuEvent* event)
+void c2bTextBrowser::contextMenuEvent(QContextMenuEvent* qevent)
 {
-    QMenu *edit_menu = createStandardContextMenu();
+    QMenu* edit_menu = createStandardContextMenu();
     edit_menu->setTitle(tr("Edit..."));
-    QMenu *menu = new QMenu(this);
+    QMenu* menu = new QMenu(this);
     menu->addMenu(edit_menu);
     QList<QAction*> acts = actions();
     for (int i = 0; i < acts.count(); ++i)
         menu->addAction(acts.at(i));
-    menu->exec(event->globalPos());
+    menu->exec(qevent->globalPos());
     delete edit_menu;
     delete menu;
 }
 
 void c2bTextBrowser::updateHtml(const QString& newHtml)
 {
-    int scrollPosition = verticalScrollBar()->value();
+    const int scrollPosition(verticalScrollBar()->value());
     setHtml(newHtml);
     verticalScrollBar()->setValue(scrollPosition);
 }
