@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BTEXTBROWSER_H
@@ -21,17 +21,18 @@ class c2bTextBrowser : public QTextBrowser
     Q_OBJECT
 
 public:
-    c2bTextBrowser(QWidget* parent = 0);
+    c2bTextBrowser(QWidget* parentw = 0);
     ~c2bTextBrowser();
 
+    void updateHtml(const QString& newHtml);
+
 
 public slots:
     virtual void setSource(const QUrl& name);
-    void updateHtml(const QString& newHtml);
 
 
 protected:
-    virtual void contextMenuEvent(QContextMenuEvent* event);
+    virtual void contextMenuEvent(QContextMenuEvent* qevent);
 
 };
 
