@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextEdit.h"
@@ -12,16 +12,25 @@
 #include <QKeyEvent>
 #include <QList>
 #include <QMenu>
+#include <QPainter>
 #include <QScrollBar>
 #include <QTextBlock>
 #include <QTextCursor>
 
 
-c2bTextEdit::c2bTextEdit(QWidget* parent) : QTextEdit(parent)
+c2bTextEdit::c2bTextEdit(QWidget* parentw) : QPlainTextEdit(parentw)
 {
-    setFrameShape(QTextEdit::StyledPanel);
-    setFrameShadow(QTextEdit::Raised);
-    setAcceptRichText(false);
+    setFrameShape(QPlainTextEdit::StyledPanel);
+    setFrameShadow(QPlainTextEdit::Raised);
+    settings = c2bSettingsP;
+    connect(settings, SIGNAL(newSettings()), this, SLOT(loadSettings()));
+
+    _line_number_area = new LineNumberArea(this);
+    _line_number_area_color = palette().color(QPalette::Active, QPalette::Base).darker(110);
+    _line_number_color_p = &settings->colors.comment_color;
+    connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth()));
+    connect(this, SIGNAL(updateRequest(const QRect&, int)), this, SLOT(updateLineNumberArea(const QRect&, int)));
+    updateLineNumberAreaWidth();
 
     c2bUtils::addSeparator(this);
     wordWrapAction = new QAction(this);
@@ -36,7 +45,7 @@ c2bTextEdit::c2bTextEdit(QWidget* parent) : QTextEdit(parent)
     wordUnWrapAction->setStatusTip(tr("Unwrap Text"));
     connect(wordUnWrapAction, SIGNAL(triggered()), this, SLOT(wordUnWrap()));
 
-    if (c2bSettingsP->value("c2bTextEdit/WrapMode", false).toBool())
+    if (settings->value("c2bTextEdit/WrapMode", false).toBool())
         wordWrap();
     else
         wordUnWrap();
@@ -44,7 +53,7 @@ c2bTextEdit::c2bTextEdit(QWidget* parent) : QTextEdit(parent)
 
 c2bTextEdit::~c2bTextEdit()
 {
-    c2bSettingsP->setValue("c2bTextEdit/WrapMode", lineWrapMode() == QTextEdit::WidgetWidth);
+    settings->setValue("c2bTextEdit/WrapMode", lineWrapMode() == QPlainTextEdit::WidgetWidth);
 }
 
 
@@ -90,20 +99,20 @@ void c2bTextEdit::setBibTeXActions()
     updateMetadataAction->setStatusTip(tr("Update Documents Metadata"));
 }
 
-void c2bTextEdit::contextMenuEvent(QContextMenuEvent * e)
+void c2bTextEdit::contextMenuEvent(QContextMenuEvent* qevent)
 {
-    QMenu *menu = createStandardContextMenu();
+    QMenu* menu = createStandardContextMenu();
     QList<QAction*> acts = actions();
     for (int i = 0; i < acts.count(); ++i)
         menu->addAction(acts.at(i));
-    menu->exec(e->globalPos());
+    menu->exec(qevent->globalPos());
     delete menu;
 }
 
-void c2bTextEdit::keyPressEvent(QKeyEvent * e)
+void c2bTextEdit::keyPressEvent(QKeyEvent* qevent)
 {
-    QTextEdit::keyPressEvent(e);
-    if (e->key() == Qt::Key_Insert)
+    QPlainTextEdit::keyPressEvent(qevent);
+    if (qevent->key() == Qt::Key_Insert)
     {
         setOverwriteMode(!overwriteMode());
         emit overwriteModeChanged();
@@ -112,27 +121,27 @@ void c2bTextEdit::keyPressEvent(QKeyEvent * e)
 
 void c2bTextEdit::wordWrap()
 {
-    setLineWrapMode(QTextEdit::WidgetWidth);
+    setLineWrapMode(QPlainTextEdit::WidgetWidth);
     wordWrapAction->setEnabled(false);
     wordUnWrapAction->setEnabled(true);
 }
 
 void c2bTextEdit::wordUnWrap()
 {
-    setLineWrapMode(QTextEdit::NoWrap);
+    setLineWrapMode(QPlainTextEdit::NoWrap);
     wordWrapAction->setEnabled(true);
     wordUnWrapAction->setEnabled(false);
 }
 
 void c2bTextEdit::updatePlainText(const QString& newText)
 {
-    int scrollPosition = verticalScrollBar()->value();
-    int cursorBlock = textCursor().blockNumber();
-    int cursorColumn = textCursor().columnNumber();
+    const int scrollPosition(verticalScrollBar()->value());
+    const int cursorBlock(textCursor().blockNumber());
+    const int cursorColumn(textCursor().columnNumber());
     setPlainText(newText);
 
     QTextBlock p = document()->begin();
-    int i = 0;
+    int i(0);
     while (p.isValid())
     {
         if (cursorBlock == i)
@@ -140,15 +149,15 @@ void c2bTextEdit::updatePlainText(const QString& newText)
         i++;
         p = p.next();
     }
-    QTextCursor cursor = textCursor();
-    cursor.setPosition(p.position() + cursorColumn, QTextCursor::MoveAnchor);
-    setTextCursor(cursor);
+    QTextCursor tcursor = textCursor();
+    tcursor.setPosition(p.position() + cursorColumn, QTextCursor::MoveAnchor);
+    setTextCursor(tcursor);
     verticalScrollBar()->setValue(scrollPosition);
 }
 
 void c2bTextEdit::convert2LaTeX()
 {
-    QString txt = textCursor().selectedText();
+    QString txt(textCursor().selectedText());
     // Better do the long way: Convert anything to c2b, and then
     // translate to TeX
     c2bUtils::fullBibToC2b(txt);
@@ -157,9 +166,87 @@ void c2bTextEdit::convert2LaTeX()
 
 void c2bTextEdit::convert2Unicode()
 {
-    QString txt = textCursor().selectedText();
+    QString txt(textCursor().selectedText());
     // Strictly, this should be bibToC2b; but convert also
     // possible PNAS like, and, for consistency, HTML sub
     // and superscripts to TeX
     insertPlainText(c2bUtils::fullBibToC2b(txt));
 }
+
+void c2bTextEdit::loadSettings()
+{
+    if (font() != settings->c2bMonoFont)
+    {
+        setFont(settings->c2bMonoFont);
+        updateLineNumberAreaWidth();
+    }
+    _line_number_area->update(); // Update, otherwise number colors might not follow apply button
+}
+
+
+/***************************************************************************
+ *  Line number area (From CodeEditor Qt's example)
+ ***************************************************************************/
+
+int c2bTextEdit::lineNumberAreaWidth()
+{
+    int digits(1);
+    int max(qMax(1, blockCount()));
+    while (max >= 10)
+    {
+        max /= 10;
+        ++digits;
+    }
+    const int space(5 + fontMetrics().width(QLatin1Char('9')) * digits);
+    return space;
+}
+
+void c2bTextEdit::updateLineNumberAreaWidth()
+{
+    setViewportMargins(lineNumberAreaWidth(), 0, 0, 0);
+}
+
+void c2bTextEdit::updateLineNumberArea(const QRect& qrect, int dy)
+{
+    if (dy)
+        _line_number_area->scroll(0, dy);
+    else
+        _line_number_area->update(0, qrect.y(), _line_number_area->width(), qrect.height());
+    if (qrect.contains(viewport()->rect()))
+        updateLineNumberAreaWidth();
+}
+
+void c2bTextEdit::resizeEvent(QResizeEvent* qevent)
+{
+    QPlainTextEdit::resizeEvent(qevent);
+    QRect cr = contentsRect();
+    _line_number_area->setGeometry(QRect(cr.left(), cr.top(), lineNumberAreaWidth(), cr.height()));
+}
+
+void c2bTextEdit::lineNumberAreaPaintEvent(QPaintEvent* qevent)
+{
+    QPainter painter(_line_number_area);
+    painter.fillRect(qevent->rect(), _line_number_area_color);
+    painter.setPen(*_line_number_color_p);
+    QFont f = font();
+    f.setPointSize(qMax(0, f.pointSize() - 3));
+    painter.setFont(f);
+
+    QTextBlock block = firstVisibleBlock();
+    int blockNumber(block.blockNumber());
+    int top(int(blockBoundingGeometry(block).translated(contentOffset()).top()));
+    int bottom(top + int(blockBoundingRect(block).height()));
+
+    while (block.isValid() && top <= qevent->rect().bottom())
+    {
+        if (block.isVisible() && bottom >= qevent->rect().top())
+        {
+            const QString number(QString::number(blockNumber + 1));
+            painter.drawText(5, top + 2, _line_number_area->width(), fontMetrics().height(), Qt::AlignLeft, number);
+        }
+        block = block.next();
+        top = bottom;
+        bottom = top + (int)blockBoundingRect(block).height();
+        ++blockNumber;
+    }
+}
