@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BUPDATEMETADATA_H
@@ -22,7 +22,7 @@ class c2bUpdateMetadata : public QDialog
     Q_OBJECT
 
 public:
-    c2bUpdateMetadata(QWidget* parent = 0);
+    c2bUpdateMetadata(QWidget* parentw = 0);
     ~c2bUpdateMetadata();
 
     void update(const QString& fn, const QString& bibtex);
@@ -35,13 +35,13 @@ private slots:
 
 
 private:
-    QPushButton* buttonAbort;
+    QPushButton* _buttonAbort;
     QString _bibtex;
     QString _fn;
     Ui::c2bLogWidget ui;
     bool _aborted;
     bool needsUpdating(const bibReference& ref, const bibReference& mref);
-    c2bBibParser* bp;
+    c2bBibParser* _bpP;
     void writeDifferences(const bibReference& ref, const bibReference& mref);
 
 };
