@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_H
@@ -13,15 +13,13 @@
 #include <QMainWindow>
 #include <QPointer>
 
-
-class c2bBibHighlighter;
+class bibSearcher;
+class c2bBibMenu;
 class c2bBibParser;
-class c2bBibSearcher;
+class c2bCiter;
 class c2bClipEdit;
 class c2bClipboard;
-class c2bConfigure;
 class c2bEditor;
-class c2bNetwork;
 class c2bNetworkQuery;
 class c2bPdfImport;
 class c2bSearchInFiles;
@@ -35,44 +33,51 @@ class cb2Bib : public QMainWindow
     Q_OBJECT
 
 public:
-    cb2Bib(QWidget* parent = 0);
+    cb2Bib(QWidget* parentw = 0);
     ~cb2Bib();
 
 
+public slots:
+    void show();
+
+
 signals:
     void addedBibToFile(const QString&);
     void endedProcessing(bool status);
 
 
 private:
-    QAction* bib_menu_any_pattern_action;
-    QHash<QString, c2bEditor*> openDocuments;
-    QHash<QString, c2bLineEdit*> bibFields;
-    QMenu* bib_menu;
-    QPointer<c2bPdfImport> pdfImport;
-    QPointer<c2bSearchInFiles> searchInFiles;
-    QString m_dropped_article_file;
-    QString m_target_article_file;
-    QString raw_input_data;
+    QHash<QString, c2bEditor*> _openDocuments;
+    QPointer<c2bPdfImport> _pdfImportP;
+    QPointer<c2bSearchInFiles> _searchInFilesP;
+    QString _dropped_document_file;
+    QString _raw_input_data;
+    QString _target_document_file;
     Ui::cb2Bib ui;
-    bool m_connected;
-    bool m_modified;
-    bool taggedViewMode;
-    c2bBibHighlighter* bibS;
-    c2bBibParser* bp;
+    bool _connected;
+    bool _is_check_repeated_done;
+    bool _modified;
+    bool _taggedViewMode;
+    bool isReferenceRepeated();
+    c2bBibMenu* _bib_menu;
+    c2bBibParser* _bpP;
+    c2bCiter* _citerP;
+    c2bClipEdit* BibBrowser;
     c2bClipEdit* ClipEdit;
-    c2bClipboard* cb;
-    c2bNetworkQuery* netQ;
-    c2bSettings* settings;
+    c2bClipboard* _cbP;
+    c2bNetworkQuery* _netQP;
+    c2bSettings* _settingsP;
     c2bTextBrowser* AboutBrowser;
-    c2bTextBrowser* BibBrowser;
-    void closeEvent(QCloseEvent* ce);
-    void dragEnterEvent(QDragEnterEvent* event);
-    void dropEvent(QDropEvent* event);
+    void c2bParse(const QString& text);
+    void c2bPreparse(const QString& text);
+    void closeEvent(QCloseEvent* qevent);
+    void dragEnterEvent(QDragEnterEvent* qevent);
+    void dropEvent(QDropEvent* qevent);
     void fileDroppedByUser(const QString& fn);
     void initAsBibTeXEditor();
+    void processingEnded();
     void setBibMenu();
-    void setBibWidgetMapping();
+    void setWidgetMapping();
     void updateBibfile(const QString& fn);
     void updateViewButtons();
 
@@ -80,24 +85,25 @@ private:
 private slots:
     void abbreviationsEditor();
     void addAuthors();
-    void addEditor();
+    void addEditors();
     void addToFile(bool ready);
     void anyPattern();
-    void bibEditor(const QString& bibtexfile, c2bBibSearcher* searcher = 0);
-    void bibModified();
+    void bibEditor(const QString& bibtexfile, bibSearcher* searcher = 0);
+    void bibModified(bool modified);
     void bookmarksEditor();
     void c2bInit();
-    void dataChanged(const QString&);
+    void checkRepeated();
+    void dataChanged(const QString& str);
     void deleteTmpBib();
     void doSearchInFiles(const QString& string = QString(), const QString& fn = QString());
     void fileDropped(const QString& fn);
-    void forceDataChange(const QString&);
+    void forceDataChange(const QString& str);
     void guessFields();
     void insertRegExp();
     void linkClicked(const QUrl& ln);
     void loadSettings();
     void makeNetQuery();
-    void netQueryEnded(bool, const QString&, const QString&);
+    void netQueryEnded(bool stat, const QString& targetPDF, const QString& targetBib);
     void on_PdfImportB_clicked();
     void on_addBibB_clicked();
     void on_configureB_clicked();
@@ -109,20 +115,21 @@ private slots:
     void on_searchInFilesB_clicked();
     void on_viewAboutB_clicked();
     void on_viewBibB_clicked();
+    void openAnnote();
     void openFileDocument();
     void postprocessBibTeX();
-    void preParserEnded(const QString&);
     void preparseClipboard();
-    void processingEnded();
-    void readField();
+    void readField(const QPoint& position);
     void regExpsEditor();
     void restartEngine();
-    void savePattern(const QString&, const QString&);
+    void savePattern(const QString& rx, const QString& rxname);
     void selectFile();
-    void setArticleFileName();
+    void setDocumentFilename();
     void setTaggedClipEditMode(bool tagged);
+    void setWindowTitle(const QString& title = QString());
     void showLink(const QString& ln);
     void showMessage(const QString& ms);
+    void updateCheckRepeatedAction();
     void updateOpenDocuments(QObject* obj);
     void updateOpenDocuments(const QString& old_name, const QString& new_name);
 
