@@ -1,7 +1,7 @@
 /***************************************************************************
  *   clipboardPoll, modified by Pere Constans for the cb2Bib, 2005
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *
  *
  *   Author and Copyright (C) 2003 by Lubos Lunak <l.lunak@kde.org>
@@ -55,14 +55,13 @@ changed in this case --- this is what is meant by REFUSED below.
 
 */
 
-clipboardPoll::clipboardPoll(QWidget* parent) : QWidget(parent)
+clipboardPoll::clipboardPoll(QWidget* parentw) : QWidget(parentw)
 {
     //     kapp->installX11EventFilter( this );
     timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
 
-    const char* names[ 6 ]
-    =
+    const char* names[ 6 ] =
         { "_QT_SELECTION_SENTINEL",
           "_QT_CLIPBOARD_SENTINEL",
           "CLIPBOARD",
@@ -80,7 +79,7 @@ clipboardPoll::clipboardPoll(QWidget* parent) : QWidget(parent)
     clipboard.timestamp_atom = atoms[ 5 ];
     selection.atom = XA_PRIMARY;
     clipboard.atom = xa_clipboard;
-    selection.last_change = clipboard.last_change = QX11Info::appTime();   // don't trigger right after startup
+    selection.last_change = clipboard.last_change = QX11Info::appTime(); // don't trigger right after startup
     selection.last_owner = XGetSelectionOwner(QX11Info::display(), XA_PRIMARY);
     clipboard.last_owner = XGetSelectionOwner(QX11Info::display(), xa_clipboard);
     selection.waiting_for_timestamp = false;
