@@ -1,46 +1,46 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *   findDialog was originally adapted from Qt Designer
  *   Copyright (C) 2001 Trolltech AS.  All rights reserved.
  ***************************************************************************/
 #include "findDialog.h"
 
+#include <QPlainTextEdit>
 #include <QPushButton>
 #include <QScrollBar>
 #include <QTextEdit>
 
 
-findDialog::findDialog(QWidget* parent) : QDialog(parent)
+findDialog::findDialog(QWidget* parentw) : QDialog(parentw)
 {
     ui.setupUi(this);
     resize(size().width(), 1);
     ui.buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Find"));
-    _editor = qobject_cast<QTextEdit*>(parent);
-    m_find_pattern = "";
+    _editor = 0;
 
     QAction* act = new QAction(this);
     act->setSeparator(true);
     addAction(act);
     findAction = new QAction(this);
     addAction(findAction);
-    findAction->setShortcut(tr("Ctrl+F"));
+    findAction->setShortcut(QKeySequence::Find);
     findAction->setText(tr("Find in Text"));
     findAction->setStatusTip(tr("Find in Text"));
     connect(findAction, SIGNAL(triggered()), this, SLOT(findText()));
 
     findNextAction = new QAction(this);
     addAction(findNextAction);
-    findNextAction->setShortcut(tr("F3"));
+    findNextAction->setShortcut(QKeySequence::FindNext);
     findNextAction->setText(tr("Find Next"));
     findNextAction->setStatusTip(tr("Find Next Occurrence"));
     connect(findNextAction, SIGNAL(triggered()), this, SLOT(findNext()));
 
     findPreviousAction = new QAction(this);
     addAction(findPreviousAction);
-    findPreviousAction->setShortcut(tr("Shift+F3"));
+    findPreviousAction->setShortcut(QKeySequence::FindPrevious);
     findPreviousAction->setText(tr("Find Previous"));
     findPreviousAction->setStatusTip(tr("Find Previous Occurrence"));
     connect(findPreviousAction, SIGNAL(triggered()), this, SLOT(findPrevious()));
@@ -54,10 +54,18 @@ void findDialog::init()
 {
     ui.notFound->hide();
     raise();
-    ui.comboFind->setEditText(_editor->textCursor().selectedText().trimmed());
+    if (_editor->inherits("QPlainTextEdit"))
+        ui.comboFind->setEditText(qobject_cast<QPlainTextEdit*>(_editor)->textCursor().selectedText().trimmed());
+    else if (_editor->inherits("QTextEdit"))
+        ui.comboFind->setEditText(qobject_cast<QTextEdit*>(_editor)->textCursor().selectedText().trimmed());
     ui.comboFind->setFocus();
 }
 
+void findDialog::setEditor(QPlainTextEdit* editor)
+{
+    _editor = editor;
+}
+
 void findDialog::setEditor(QTextEdit* editor)
 {
     _editor = editor;
@@ -98,29 +106,43 @@ void findDialog::findText()
     show();
 }
 
-bool findDialog::findText(const QString& pattern, bool forward, bool caseSensitive, bool wholeWords)
+bool findDialog::findText(const QString& pattern, bool do_forward, bool do_case_sensitive, bool do_whole_words)
 {
     if (pattern.isEmpty())
         return false;
     m_find_pattern = pattern;
-    m_find_case = caseSensitive;
-    m_find_words = wholeWords;
+    m_find_case = do_case_sensitive;
+    m_find_words = do_whole_words;
 
-    QTextDocument *doc = _editor->document();
-    QTextCursor c = _editor->textCursor();
+    QTextDocument* doc;
+    QTextCursor c;
+    if (_editor->inherits("QPlainTextEdit"))
+    {
+        QPlainTextEdit* ed = qobject_cast<QPlainTextEdit*>(_editor);
+        doc = ed->document();
+        c = ed->textCursor();
+    }
+    else if (_editor->inherits("QTextEdit"))
+    {
+        QTextEdit* ed = qobject_cast<QTextEdit*>(_editor);
+        doc = ed->document();
+        c = ed->textCursor();
+    }
+    else
+        return false;
     QTextDocument::FindFlags options;
 
     if (c.hasSelection())
-        c.setPosition(forward ? c.position() : c.anchor(), QTextCursor::MoveAnchor);
+        c.setPosition(do_forward ? c.position() : c.anchor(), QTextCursor::MoveAnchor);
     QTextCursor newCursor = c;
-    if (!forward)
+    if (!do_forward)
         options |= QTextDocument::FindBackward;
     if (m_find_case)
         options |= QTextDocument::FindCaseSensitively;
     if (m_find_words)
         options |= QTextDocument::FindWholeWords;
     newCursor = doc->find(m_find_pattern, c, options);
-    bool found = true;
+    bool found(true);
     if (newCursor.isNull())
     {
         QTextCursor ac(doc);
@@ -132,9 +154,20 @@ bool findDialog::findText(const QString& pattern, bool forward, bool caseSensiti
             found = false;
         }
     }
-    _editor->setTextCursor(newCursor);
-    _editor->verticalScrollBar()->setValue(_editor->verticalScrollBar()->maximum());
-    _editor->ensureCursorVisible();
+    if (_editor->inherits("QPlainTextEdit"))
+    {
+        QPlainTextEdit* ed = qobject_cast<QPlainTextEdit*>(_editor);
+        ed->setTextCursor(newCursor);
+        ed->verticalScrollBar()->setValue(ed->verticalScrollBar()->maximum());
+        ed->ensureCursorVisible();
+    }
+    else if (_editor->inherits("QTextEdit"))
+    {
+        QTextEdit* ed = qobject_cast<QTextEdit*>(_editor);
+        ed->setTextCursor(newCursor);
+        ed->verticalScrollBar()->setValue(ed->verticalScrollBar()->maximum());
+        ed->ensureCursorVisible();
+    }
     return found;
 }
 
