@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2008 by Pere Constans
+ *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.0.4. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *   findDialog is adapted from Qt Designer
  *   Copyright (C) 2001 Trolltech AS.  All rights reserved.
@@ -15,6 +15,7 @@
 #include <QPointer>
 
 
+class QPlainTextEdit;
 class QTextEdit;
 
 
@@ -24,7 +25,7 @@ class findDialog : public QDialog
     Q_OBJECT
 
 public:
-    findDialog(QWidget* parent = 0);
+    findDialog(QWidget* parentw = 0);
     ~findDialog();
 
     QAction* findAction;
@@ -37,6 +38,7 @@ public slots:
     void findNext();
     void findPrevious();
     void findText();
+    void setEditor(QPlainTextEdit* editor);
     void setEditor(QTextEdit* editor);
     void show();
 
@@ -46,12 +48,12 @@ private slots:
 
 
 private:
-    bool findText(const QString& pattern, bool forward = true, bool caseSensitive = false, bool wholeWords = false);
-    bool m_find_case;
-    bool m_find_words;
-    QPointer<QTextEdit> _editor;
+    QPointer<QWidget> _editor;
     QString m_find_pattern;
     Ui::findDialog ui;
+    bool findText(const QString& pattern, bool do_forward = true, bool do_case_sensitive = false, bool do_whole_words = false);
+    bool m_find_case;
+    bool m_find_words;
     void init();
 
 };
